/****************************************************************************
** Meta object code from reading C++ file 'monthview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/month/monthview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monthview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__MonthView_t {
    QByteArrayData data[21];
    char stringdata0[297];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__MonthView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__MonthView_t qt_meta_stringdata_EventViews__MonthView = {
    {
QT_MOC_LITERAL(0, 0, 21), // "EventViews::MonthView"
QT_MOC_LITERAL(1, 22, 24), // "showIncidencePopupSignal"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 13), // "Akonadi::Item"
QT_MOC_LITERAL(4, 62, 4), // "item"
QT_MOC_LITERAL(5, 67, 4), // "date"
QT_MOC_LITERAL(6, 72, 23), // "showNewEventPopupSignal"
QT_MOC_LITERAL(7, 96, 15), // "fullViewChanged"
QT_MOC_LITERAL(8, 112, 7), // "enabled"
QT_MOC_LITERAL(9, 120, 12), // "updateConfig"
QT_MOC_LITERAL(10, 133, 10), // "updateView"
QT_MOC_LITERAL(11, 144, 14), // "showIncidences"
QT_MOC_LITERAL(12, 159, 19), // "Akonadi::Item::List"
QT_MOC_LITERAL(13, 179, 13), // "incidenceList"
QT_MOC_LITERAL(14, 193, 22), // "changeIncidenceDisplay"
QT_MOC_LITERAL(15, 216, 14), // "changeFullView"
QT_MOC_LITERAL(16, 231, 13), // "moveBackMonth"
QT_MOC_LITERAL(17, 245, 12), // "moveBackWeek"
QT_MOC_LITERAL(18, 258, 11), // "moveFwdWeek"
QT_MOC_LITERAL(19, 270, 12), // "moveFwdMonth"
QT_MOC_LITERAL(20, 283, 13) // "calendarReset"

    },
    "EventViews::MonthView\0showIncidencePopupSignal\0"
    "\0Akonadi::Item\0item\0date\0"
    "showNewEventPopupSignal\0fullViewChanged\0"
    "enabled\0updateConfig\0updateView\0"
    "showIncidences\0Akonadi::Item::List\0"
    "incidenceList\0changeIncidenceDisplay\0"
    "changeFullView\0moveBackMonth\0moveBackWeek\0"
    "moveFwdWeek\0moveFwdMonth\0calendarReset"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__MonthView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   79,    2, 0x06 /* Public */,
       6,    0,   84,    2, 0x06 /* Public */,
       7,    1,   85,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,   88,    2, 0x0a /* Public */,
      10,    0,   89,    2, 0x0a /* Public */,
      11,    2,   90,    2, 0x0a /* Public */,
      14,    2,   95,    2, 0x0a /* Public */,
      15,    0,  100,    2, 0x0a /* Public */,
      16,    0,  101,    2, 0x0a /* Public */,
      17,    0,  102,    2, 0x0a /* Public */,
      18,    0,  103,    2, 0x0a /* Public */,
      19,    0,  104,    2, 0x0a /* Public */,
      20,    0,  105,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QDate,    4,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    8,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12, QMetaType::QDate,   13,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void EventViews::MonthView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MonthView *_t = static_cast<MonthView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showIncidencePopupSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 1: _t->showNewEventPopupSignal(); break;
        case 2: _t->fullViewChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->updateConfig(); break;
        case 4: _t->updateView(); break;
        case 5: _t->showIncidences((*reinterpret_cast< const Akonadi::Item::List(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 6: _t->changeIncidenceDisplay((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->changeFullView(); break;
        case 8: _t->moveBackMonth(); break;
        case 9: _t->moveBackWeek(); break;
        case 10: _t->moveFwdWeek(); break;
        case 11: _t->moveFwdMonth(); break;
        case 12: _t->calendarReset(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item::List >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MonthView::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MonthView::showIncidencePopupSignal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MonthView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MonthView::showNewEventPopupSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MonthView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MonthView::fullViewChanged)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject EventViews::MonthView::staticMetaObject = {
    { &EventView::staticMetaObject, qt_meta_stringdata_EventViews__MonthView.data,
      qt_meta_data_EventViews__MonthView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::MonthView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::MonthView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__MonthView.stringdata0))
        return static_cast<void*>(this);
    return EventView::qt_metacast(_clname);
}

int EventViews::MonthView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void EventViews::MonthView::showIncidencePopupSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void EventViews::MonthView::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EventViews::MonthView::fullViewChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
