/****************************************************************************
** Meta object code from reading C++ file 'decorationlabel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/agenda/decorationlabel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationlabel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__DecorationLabel_t {
    QByteArrayData data[14];
    char stringdata0[185];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__DecorationLabel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__DecorationLabel_t qt_meta_stringdata_EventViews__DecorationLabel = {
    {
QT_MOC_LITERAL(0, 0, 27), // "EventViews::DecorationLabel"
QT_MOC_LITERAL(1, 28, 16), // "setExtensiveText"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 11), // "setLongText"
QT_MOC_LITERAL(4, 58, 9), // "setPixmap"
QT_MOC_LITERAL(5, 68, 12), // "setShortText"
QT_MOC_LITERAL(6, 81, 7), // "setText"
QT_MOC_LITERAL(7, 89, 6), // "setUrl"
QT_MOC_LITERAL(8, 96, 12), // "useShortText"
QT_MOC_LITERAL(9, 109, 21), // "allowAutomaticSqueeze"
QT_MOC_LITERAL(10, 131, 11), // "useLongText"
QT_MOC_LITERAL(11, 143, 16), // "useExtensiveText"
QT_MOC_LITERAL(12, 160, 9), // "usePixmap"
QT_MOC_LITERAL(13, 170, 14) // "useDefaultText"

    },
    "EventViews::DecorationLabel\0"
    "setExtensiveText\0\0setLongText\0setPixmap\0"
    "setShortText\0setText\0setUrl\0useShortText\0"
    "allowAutomaticSqueeze\0useLongText\0"
    "useExtensiveText\0usePixmap\0useDefaultText"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__DecorationLabel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x0a /* Public */,
       3,    1,   92,    2, 0x0a /* Public */,
       4,    1,   95,    2, 0x0a /* Public */,
       5,    1,   98,    2, 0x0a /* Public */,
       6,    1,  101,    2, 0x0a /* Public */,
       7,    1,  104,    2, 0x0a /* Public */,
       8,    1,  107,    2, 0x0a /* Public */,
       8,    0,  110,    2, 0x2a /* Public | MethodCloned */,
      10,    1,  111,    2, 0x0a /* Public */,
      10,    0,  114,    2, 0x2a /* Public | MethodCloned */,
      11,    1,  115,    2, 0x0a /* Public */,
      11,    0,  118,    2, 0x2a /* Public | MethodCloned */,
      12,    1,  119,    2, 0x0a /* Public */,
      12,    0,  122,    2, 0x2a /* Public | MethodCloned */,
      13,    0,  123,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QPixmap,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QUrl,    2,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void EventViews::DecorationLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DecorationLabel *_t = static_cast<DecorationLabel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setExtensiveText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->setLongText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->setPixmap((*reinterpret_cast< const QPixmap(*)>(_a[1]))); break;
        case 3: _t->setShortText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->setUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 6: _t->useShortText((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->useShortText(); break;
        case 8: _t->useLongText((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->useLongText(); break;
        case 10: _t->useExtensiveText((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->useExtensiveText(); break;
        case 12: _t->usePixmap((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->usePixmap(); break;
        case 14: _t->useDefaultText(); break;
        default: ;
        }
    }
}

const QMetaObject EventViews::DecorationLabel::staticMetaObject = {
    { &QLabel::staticMetaObject, qt_meta_stringdata_EventViews__DecorationLabel.data,
      qt_meta_data_EventViews__DecorationLabel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::DecorationLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::DecorationLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__DecorationLabel.stringdata0))
        return static_cast<void*>(this);
    return QLabel::qt_metacast(_clname);
}

int EventViews::DecorationLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
