/****************************************************************************
** Meta object code from reading C++ file 'journalframe.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/journal/journalframe.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journalframe.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__JournalFrame_t {
    QByteArrayData data[18];
    char stringdata0[249];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__JournalFrame_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__JournalFrame_t qt_meta_stringdata_EventViews__JournalFrame = {
    {
QT_MOC_LITERAL(0, 0, 24), // "EventViews::JournalFrame"
QT_MOC_LITERAL(1, 25, 12), // "printJournal"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 22), // "KCalCore::Journal::Ptr"
QT_MOC_LITERAL(4, 62, 7), // "preview"
QT_MOC_LITERAL(5, 70, 15), // "deleteIncidence"
QT_MOC_LITERAL(6, 86, 13), // "Akonadi::Item"
QT_MOC_LITERAL(7, 100, 13), // "editIncidence"
QT_MOC_LITERAL(8, 114, 17), // "incidenceSelected"
QT_MOC_LITERAL(9, 132, 8), // "setDirty"
QT_MOC_LITERAL(10, 141, 10), // "deleteItem"
QT_MOC_LITERAL(11, 152, 8), // "editItem"
QT_MOC_LITERAL(12, 161, 19), // "printPreviewJournal"
QT_MOC_LITERAL(13, 181, 19), // "setIncidenceChanger"
QT_MOC_LITERAL(14, 201, 26), // "Akonadi::IncidenceChanger*"
QT_MOC_LITERAL(15, 228, 7), // "changer"
QT_MOC_LITERAL(16, 236, 7), // "setDate"
QT_MOC_LITERAL(17, 244, 4) // "date"

    },
    "EventViews::JournalFrame\0printJournal\0"
    "\0KCalCore::Journal::Ptr\0preview\0"
    "deleteIncidence\0Akonadi::Item\0"
    "editIncidence\0incidenceSelected\0"
    "setDirty\0deleteItem\0editItem\0"
    "printPreviewJournal\0setIncidenceChanger\0"
    "Akonadi::IncidenceChanger*\0changer\0"
    "setDate\0date"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__JournalFrame[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   69,    2, 0x06 /* Public */,
       5,    1,   74,    2, 0x06 /* Public */,
       7,    1,   77,    2, 0x06 /* Public */,
       8,    2,   80,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,   85,    2, 0x09 /* Protected */,
      10,    0,   86,    2, 0x09 /* Protected */,
      11,    0,   87,    2, 0x09 /* Protected */,
       1,    0,   88,    2, 0x09 /* Protected */,
      12,    0,   89,    2, 0x09 /* Protected */,
      13,    1,   90,    2, 0x0a /* Public */,
      16,    1,   93,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    2,    4,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QDate,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::QDate,   17,

       0        // eod
};

void EventViews::JournalFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JournalFrame *_t = static_cast<JournalFrame *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->printJournal((*reinterpret_cast< const KCalCore::Journal::Ptr(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->deleteIncidence((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 2: _t->editIncidence((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 3: _t->incidenceSelected((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 4: _t->setDirty(); break;
        case 5: _t->deleteItem(); break;
        case 6: _t->editItem(); break;
        case 7: _t->printJournal(); break;
        case 8: _t->printPreviewJournal(); break;
        case 9: _t->setIncidenceChanger((*reinterpret_cast< Akonadi::IncidenceChanger*(*)>(_a[1]))); break;
        case 10: _t->setDate((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KCalCore::Journal::Ptr >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JournalFrame::*_t)(const KCalCore::Journal::Ptr & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalFrame::printJournal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (JournalFrame::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalFrame::deleteIncidence)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (JournalFrame::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalFrame::editIncidence)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (JournalFrame::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalFrame::incidenceSelected)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject EventViews::JournalFrame::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_EventViews__JournalFrame.data,
      qt_meta_data_EventViews__JournalFrame,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::JournalFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::JournalFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__JournalFrame.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int EventViews::JournalFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void EventViews::JournalFrame::printJournal(const KCalCore::Journal::Ptr & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void EventViews::JournalFrame::deleteIncidence(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void EventViews::JournalFrame::editIncidence(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void EventViews::JournalFrame::incidenceSelected(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
struct qt_meta_stringdata_EventViews__JournalDateView_t {
    QByteArrayData data[20];
    char stringdata0[306];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__JournalDateView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__JournalDateView_t qt_meta_stringdata_EventViews__JournalDateView = {
    {
QT_MOC_LITERAL(0, 0, 27), // "EventViews::JournalDateView"
QT_MOC_LITERAL(1, 28, 25), // "setIncidenceChangerSignal"
QT_MOC_LITERAL(2, 54, 0), // ""
QT_MOC_LITERAL(3, 55, 26), // "Akonadi::IncidenceChanger*"
QT_MOC_LITERAL(4, 82, 7), // "changer"
QT_MOC_LITERAL(5, 90, 13), // "setDateSignal"
QT_MOC_LITERAL(6, 104, 12), // "flushEntries"
QT_MOC_LITERAL(7, 117, 13), // "editIncidence"
QT_MOC_LITERAL(8, 131, 13), // "Akonadi::Item"
QT_MOC_LITERAL(9, 145, 7), // "journal"
QT_MOC_LITERAL(10, 153, 15), // "deleteIncidence"
QT_MOC_LITERAL(11, 169, 10), // "newJournal"
QT_MOC_LITERAL(12, 180, 17), // "incidenceSelected"
QT_MOC_LITERAL(13, 198, 12), // "printJournal"
QT_MOC_LITERAL(14, 211, 22), // "KCalCore::Journal::Ptr"
QT_MOC_LITERAL(15, 234, 7), // "preview"
QT_MOC_LITERAL(16, 242, 14), // "emitNewJournal"
QT_MOC_LITERAL(17, 257, 19), // "setIncidenceChanger"
QT_MOC_LITERAL(18, 277, 13), // "journalEdited"
QT_MOC_LITERAL(19, 291, 14) // "journalDeleted"

    },
    "EventViews::JournalDateView\0"
    "setIncidenceChangerSignal\0\0"
    "Akonadi::IncidenceChanger*\0changer\0"
    "setDateSignal\0flushEntries\0editIncidence\0"
    "Akonadi::Item\0journal\0deleteIncidence\0"
    "newJournal\0incidenceSelected\0printJournal\0"
    "KCalCore::Journal::Ptr\0preview\0"
    "emitNewJournal\0setIncidenceChanger\0"
    "journalEdited\0journalDeleted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__JournalDateView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       5,    1,   77,    2, 0x06 /* Public */,
       6,    0,   80,    2, 0x06 /* Public */,
       7,    1,   81,    2, 0x06 /* Public */,
      10,    1,   84,    2, 0x06 /* Public */,
      11,    1,   87,    2, 0x06 /* Public */,
      12,    2,   90,    2, 0x06 /* Public */,
      13,    2,   95,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,  100,    2, 0x0a /* Public */,
      17,    1,  101,    2, 0x0a /* Public */,
      18,    1,  104,    2, 0x0a /* Public */,
      19,    1,  107,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QDate,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::QDate,    2,
    QMetaType::Void, 0x80000000 | 8, QMetaType::QDate,    2,    2,
    QMetaType::Void, 0x80000000 | 14, QMetaType::Bool,    2,   15,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, 0x80000000 | 8,    2,

       0        // eod
};

void EventViews::JournalDateView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JournalDateView *_t = static_cast<JournalDateView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setIncidenceChangerSignal((*reinterpret_cast< Akonadi::IncidenceChanger*(*)>(_a[1]))); break;
        case 1: _t->setDateSignal((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 2: _t->flushEntries(); break;
        case 3: _t->editIncidence((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 4: _t->deleteIncidence((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 5: _t->newJournal((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 6: _t->incidenceSelected((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 7: _t->printJournal((*reinterpret_cast< const KCalCore::Journal::Ptr(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: _t->emitNewJournal(); break;
        case 9: _t->setIncidenceChanger((*reinterpret_cast< Akonadi::IncidenceChanger*(*)>(_a[1]))); break;
        case 10: _t->journalEdited((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 11: _t->journalDeleted((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KCalCore::Journal::Ptr >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JournalDateView::*_t)(Akonadi::IncidenceChanger * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalDateView::setIncidenceChangerSignal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (JournalDateView::*_t)(const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalDateView::setDateSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (JournalDateView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalDateView::flushEntries)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (JournalDateView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalDateView::editIncidence)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (JournalDateView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalDateView::deleteIncidence)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (JournalDateView::*_t)(const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalDateView::newJournal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (JournalDateView::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalDateView::incidenceSelected)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (JournalDateView::*_t)(const KCalCore::Journal::Ptr & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalDateView::printJournal)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject EventViews::JournalDateView::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_EventViews__JournalDateView.data,
      qt_meta_data_EventViews__JournalDateView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::JournalDateView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::JournalDateView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__JournalDateView.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int EventViews::JournalDateView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void EventViews::JournalDateView::setIncidenceChangerSignal(Akonadi::IncidenceChanger * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void EventViews::JournalDateView::setDateSignal(const QDate & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void EventViews::JournalDateView::flushEntries()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EventViews::JournalDateView::editIncidence(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void EventViews::JournalDateView::deleteIncidence(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void EventViews::JournalDateView::newJournal(const QDate & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void EventViews::JournalDateView::incidenceSelected(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void EventViews::JournalDateView::printJournal(const KCalCore::Journal::Ptr & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
