/****************************************************************************
** Meta object code from reading C++ file 'whatsnextview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/whatsnext/whatsnextview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'whatsnextview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__WhatsNextTextBrowser_t {
    QByteArrayData data[4];
    char stringdata0[52];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__WhatsNextTextBrowser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__WhatsNextTextBrowser_t qt_meta_stringdata_EventViews__WhatsNextTextBrowser = {
    {
QT_MOC_LITERAL(0, 0, 32), // "EventViews::WhatsNextTextBrowser"
QT_MOC_LITERAL(1, 33, 13), // "showIncidence"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 3) // "uid"

    },
    "EventViews::WhatsNextTextBrowser\0"
    "showIncidence\0\0uid"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__WhatsNextTextBrowser[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void EventViews::WhatsNextTextBrowser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WhatsNextTextBrowser *_t = static_cast<WhatsNextTextBrowser *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showIncidence((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (WhatsNextTextBrowser::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhatsNextTextBrowser::showIncidence)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject EventViews::WhatsNextTextBrowser::staticMetaObject = {
    { &QTextBrowser::staticMetaObject, qt_meta_stringdata_EventViews__WhatsNextTextBrowser.data,
      qt_meta_data_EventViews__WhatsNextTextBrowser,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::WhatsNextTextBrowser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::WhatsNextTextBrowser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__WhatsNextTextBrowser.stringdata0))
        return static_cast<void*>(this);
    return QTextBrowser::qt_metacast(_clname);
}

int EventViews::WhatsNextTextBrowser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextBrowser::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void EventViews::WhatsNextTextBrowser::showIncidence(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_EventViews__WhatsNextView_t {
    QByteArrayData data[15];
    char stringdata0[216];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__WhatsNextView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__WhatsNextView_t qt_meta_stringdata_EventViews__WhatsNextView = {
    {
QT_MOC_LITERAL(0, 0, 25), // "EventViews::WhatsNextView"
QT_MOC_LITERAL(1, 26, 10), // "updateView"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 9), // "showDates"
QT_MOC_LITERAL(4, 48, 5), // "start"
QT_MOC_LITERAL(5, 54, 3), // "end"
QT_MOC_LITERAL(6, 58, 14), // "preferredMonth"
QT_MOC_LITERAL(7, 73, 14), // "showIncidences"
QT_MOC_LITERAL(8, 88, 19), // "Akonadi::Item::List"
QT_MOC_LITERAL(9, 108, 13), // "incidenceList"
QT_MOC_LITERAL(10, 122, 4), // "date"
QT_MOC_LITERAL(11, 127, 22), // "changeIncidenceDisplay"
QT_MOC_LITERAL(12, 150, 13), // "Akonadi::Item"
QT_MOC_LITERAL(13, 164, 37), // "Akonadi::IncidenceChanger::Ch..."
QT_MOC_LITERAL(14, 202, 13) // "showIncidence"

    },
    "EventViews::WhatsNextView\0updateView\0"
    "\0showDates\0start\0end\0preferredMonth\0"
    "showIncidences\0Akonadi::Item::List\0"
    "incidenceList\0date\0changeIncidenceDisplay\0"
    "Akonadi::Item\0Akonadi::IncidenceChanger::ChangeType\0"
    "showIncidence"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__WhatsNextView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x0a /* Public */,
       3,    3,   40,    2, 0x0a /* Public */,
       7,    2,   47,    2, 0x0a /* Public */,
      11,    2,   52,    2, 0x0a /* Public */,
      14,    1,   57,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate, QMetaType::QDate,    4,    5,    6,
    QMetaType::Void, 0x80000000 | 8, QMetaType::QDate,    9,   10,
    QMetaType::Void, 0x80000000 | 12, 0x80000000 | 13,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void EventViews::WhatsNextView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WhatsNextView *_t = static_cast<WhatsNextView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateView(); break;
        case 1: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2])),(*reinterpret_cast< const QDate(*)>(_a[3]))); break;
        case 2: _t->showIncidences((*reinterpret_cast< const Akonadi::Item::List(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 3: _t->changeIncidenceDisplay((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< Akonadi::IncidenceChanger::ChangeType(*)>(_a[2]))); break;
        case 4: _t->showIncidence((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item::List >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        }
    }
}

const QMetaObject EventViews::WhatsNextView::staticMetaObject = {
    { &EventViews::EventView::staticMetaObject, qt_meta_stringdata_EventViews__WhatsNextView.data,
      qt_meta_data_EventViews__WhatsNextView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::WhatsNextView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::WhatsNextView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__WhatsNextView.stringdata0))
        return static_cast<void*>(this);
    return EventViews::EventView::qt_metacast(_clname);
}

int EventViews::WhatsNextView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventViews::EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
