/****************************************************************************
** Meta object code from reading C++ file 'multiagendaview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/multiagenda/multiagendaview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multiagendaview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__MultiAgendaView_t {
    QByteArrayData data[34];
    char stringdata0[511];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__MultiAgendaView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__MultiAgendaView_t qt_meta_stringdata_EventViews__MultiAgendaView = {
    {
QT_MOC_LITERAL(0, 0, 27), // "EventViews::MultiAgendaView"
QT_MOC_LITERAL(1, 28, 23), // "showNewEventPopupSignal"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 24), // "showIncidencePopupSignal"
QT_MOC_LITERAL(4, 78, 13), // "Akonadi::Item"
QT_MOC_LITERAL(5, 92, 24), // "customCollectionsChanged"
QT_MOC_LITERAL(6, 117, 22), // "ConfigDialogInterface*"
QT_MOC_LITERAL(7, 140, 3), // "dlg"
QT_MOC_LITERAL(8, 144, 9), // "showDates"
QT_MOC_LITERAL(9, 154, 5), // "start"
QT_MOC_LITERAL(10, 160, 3), // "end"
QT_MOC_LITERAL(11, 164, 14), // "preferredMonth"
QT_MOC_LITERAL(12, 179, 14), // "showIncidences"
QT_MOC_LITERAL(13, 194, 19), // "Akonadi::Item::List"
QT_MOC_LITERAL(14, 214, 13), // "incidenceList"
QT_MOC_LITERAL(15, 228, 4), // "date"
QT_MOC_LITERAL(16, 233, 10), // "updateView"
QT_MOC_LITERAL(17, 244, 12), // "updateConfig"
QT_MOC_LITERAL(18, 257, 19), // "setIncidenceChanger"
QT_MOC_LITERAL(19, 277, 26), // "Akonadi::IncidenceChanger*"
QT_MOC_LITERAL(20, 304, 7), // "changer"
QT_MOC_LITERAL(21, 312, 26), // "collectionSelectionChanged"
QT_MOC_LITERAL(22, 339, 20), // "slotSelectionChanged"
QT_MOC_LITERAL(23, 360, 26), // "slotClearTimeSpanSelection"
QT_MOC_LITERAL(24, 387, 15), // "resizeSplitters"
QT_MOC_LITERAL(25, 403, 14), // "setupScrollBar"
QT_MOC_LITERAL(26, 418, 8), // "zoomView"
QT_MOC_LITERAL(27, 427, 5), // "delta"
QT_MOC_LITERAL(28, 433, 3), // "pos"
QT_MOC_LITERAL(29, 437, 15), // "Qt::Orientation"
QT_MOC_LITERAL(30, 453, 3), // "ori"
QT_MOC_LITERAL(31, 457, 20), // "slotResizeScrollView"
QT_MOC_LITERAL(32, 478, 13), // "recreateViews"
QT_MOC_LITERAL(33, 492, 18) // "forceRecreateViews"

    },
    "EventViews::MultiAgendaView\0"
    "showNewEventPopupSignal\0\0"
    "showIncidencePopupSignal\0Akonadi::Item\0"
    "customCollectionsChanged\0"
    "ConfigDialogInterface*\0dlg\0showDates\0"
    "start\0end\0preferredMonth\0showIncidences\0"
    "Akonadi::Item::List\0incidenceList\0"
    "date\0updateView\0updateConfig\0"
    "setIncidenceChanger\0Akonadi::IncidenceChanger*\0"
    "changer\0collectionSelectionChanged\0"
    "slotSelectionChanged\0slotClearTimeSpanSelection\0"
    "resizeSplitters\0setupScrollBar\0zoomView\0"
    "delta\0pos\0Qt::Orientation\0ori\0"
    "slotResizeScrollView\0recreateViews\0"
    "forceRecreateViews"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__MultiAgendaView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  104,    2, 0x06 /* Public */,
       3,    2,  105,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,  110,    2, 0x0a /* Public */,
       8,    3,  113,    2, 0x0a /* Public */,
       8,    2,  120,    2, 0x2a /* Public | MethodCloned */,
      12,    2,  125,    2, 0x0a /* Public */,
      16,    0,  130,    2, 0x0a /* Public */,
      17,    0,  131,    2, 0x0a /* Public */,
      18,    1,  132,    2, 0x0a /* Public */,
      21,    0,  135,    2, 0x09 /* Protected */,
      22,    0,  136,    2, 0x08 /* Private */,
      23,    0,  137,    2, 0x08 /* Private */,
      24,    0,  138,    2, 0x08 /* Private */,
      25,    0,  139,    2, 0x08 /* Private */,
      26,    3,  140,    2, 0x08 /* Private */,
      31,    0,  147,    2, 0x08 /* Private */,
      32,    0,  148,    2, 0x08 /* Private */,
      33,    0,  149,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QDate,    2,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate, QMetaType::QDate,    9,   10,   11,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate,    9,   10,
    QMetaType::Void, 0x80000000 | 13, QMetaType::QDate,   14,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QPoint, 0x80000000 | 29,   27,   28,   30,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void EventViews::MultiAgendaView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MultiAgendaView *_t = static_cast<MultiAgendaView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showNewEventPopupSignal(); break;
        case 1: _t->showIncidencePopupSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 2: _t->customCollectionsChanged((*reinterpret_cast< ConfigDialogInterface*(*)>(_a[1]))); break;
        case 3: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2])),(*reinterpret_cast< const QDate(*)>(_a[3]))); break;
        case 4: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 5: _t->showIncidences((*reinterpret_cast< const Akonadi::Item::List(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 6: _t->updateView(); break;
        case 7: _t->updateConfig(); break;
        case 8: _t->setIncidenceChanger((*reinterpret_cast< Akonadi::IncidenceChanger*(*)>(_a[1]))); break;
        case 9: _t->collectionSelectionChanged(); break;
        case 10: _t->slotSelectionChanged(); break;
        case 11: _t->slotClearTimeSpanSelection(); break;
        case 12: _t->resizeSplitters(); break;
        case 13: _t->setupScrollBar(); break;
        case 14: _t->zoomView((*reinterpret_cast< const int(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2])),(*reinterpret_cast< const Qt::Orientation(*)>(_a[3]))); break;
        case 15: _t->slotResizeScrollView(); break;
        case 16: _t->recreateViews(); break;
        case 17: _t->forceRecreateViews(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item::List >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MultiAgendaView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiAgendaView::showNewEventPopupSignal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MultiAgendaView::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiAgendaView::showIncidencePopupSignal)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject EventViews::MultiAgendaView::staticMetaObject = {
    { &EventView::staticMetaObject, qt_meta_stringdata_EventViews__MultiAgendaView.data,
      qt_meta_data_EventViews__MultiAgendaView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::MultiAgendaView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::MultiAgendaView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__MultiAgendaView.stringdata0))
        return static_cast<void*>(this);
    return EventView::qt_metacast(_clname);
}

int EventViews::MultiAgendaView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void EventViews::MultiAgendaView::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::MultiAgendaView::showIncidencePopupSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
