/****************************************************************************
** Meta object code from reading C++ file 'listview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/list/listview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'listview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__ListView_t {
    QByteArrayData data[21];
    char stringdata0[295];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__ListView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__ListView_t qt_meta_stringdata_EventViews__ListView = {
    {
QT_MOC_LITERAL(0, 0, 20), // "EventViews::ListView"
QT_MOC_LITERAL(1, 21, 23), // "showNewEventPopupSignal"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 24), // "showIncidencePopupSignal"
QT_MOC_LITERAL(4, 71, 13), // "Akonadi::Item"
QT_MOC_LITERAL(5, 85, 10), // "updateView"
QT_MOC_LITERAL(6, 96, 9), // "showDates"
QT_MOC_LITERAL(7, 106, 5), // "start"
QT_MOC_LITERAL(8, 112, 3), // "end"
QT_MOC_LITERAL(9, 116, 14), // "preferredMonth"
QT_MOC_LITERAL(10, 131, 14), // "showIncidences"
QT_MOC_LITERAL(11, 146, 19), // "Akonadi::Item::List"
QT_MOC_LITERAL(12, 166, 13), // "incidenceList"
QT_MOC_LITERAL(13, 180, 4), // "date"
QT_MOC_LITERAL(14, 185, 14), // "clearSelection"
QT_MOC_LITERAL(15, 200, 22), // "changeIncidenceDisplay"
QT_MOC_LITERAL(16, 223, 17), // "defaultItemAction"
QT_MOC_LITERAL(17, 241, 17), // "Akonadi::Item::Id"
QT_MOC_LITERAL(18, 259, 2), // "id"
QT_MOC_LITERAL(19, 262, 9), // "popupMenu"
QT_MOC_LITERAL(20, 272, 22) // "processSelectionChange"

    },
    "EventViews::ListView\0showNewEventPopupSignal\0"
    "\0showIncidencePopupSignal\0Akonadi::Item\0"
    "updateView\0showDates\0start\0end\0"
    "preferredMonth\0showIncidences\0"
    "Akonadi::Item::List\0incidenceList\0"
    "date\0clearSelection\0changeIncidenceDisplay\0"
    "defaultItemAction\0Akonadi::Item::Id\0"
    "id\0popupMenu\0processSelectionChange"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__ListView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    2,   75,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   80,    2, 0x0a /* Public */,
       6,    3,   81,    2, 0x0a /* Public */,
       6,    2,   88,    2, 0x2a /* Public | MethodCloned */,
      10,    2,   93,    2, 0x0a /* Public */,
      14,    0,   98,    2, 0x0a /* Public */,
      15,    2,   99,    2, 0x0a /* Public */,
      16,    1,  104,    2, 0x0a /* Public */,
      16,    1,  107,    2, 0x0a /* Public */,
      19,    1,  110,    2, 0x0a /* Public */,
      20,    0,  113,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QDate,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate, QMetaType::QDate,    7,    8,    9,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate,    7,    8,
    QMetaType::Void, 0x80000000 | 11, QMetaType::QDate,   12,   13,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,

       0        // eod
};

void EventViews::ListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ListView *_t = static_cast<ListView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showNewEventPopupSignal(); break;
        case 1: _t->showIncidencePopupSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 2: _t->updateView(); break;
        case 3: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2])),(*reinterpret_cast< const QDate(*)>(_a[3]))); break;
        case 4: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 5: _t->showIncidences((*reinterpret_cast< const Akonadi::Item::List(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 6: _t->clearSelection(); break;
        case 7: _t->changeIncidenceDisplay((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->defaultItemAction((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 9: _t->defaultItemAction((*reinterpret_cast< const Akonadi::Item::Id(*)>(_a[1]))); break;
        case 10: _t->popupMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 11: _t->processSelectionChange(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item::List >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ListView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ListView::showNewEventPopupSignal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ListView::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ListView::showIncidencePopupSignal)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject EventViews::ListView::staticMetaObject = {
    { &EventView::staticMetaObject, qt_meta_stringdata_EventViews__ListView.data,
      qt_meta_data_EventViews__ListView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::ListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::ListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__ListView.stringdata0))
        return static_cast<void*>(this);
    return EventView::qt_metacast(_clname);
}

int EventViews::ListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void EventViews::ListView::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::ListView::showIncidencePopupSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
