/****************************************************************************
** Meta object code from reading C++ file 'monthscene.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/month/monthscene.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monthscene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__MonthScene_t {
    QByteArrayData data[8];
    char stringdata0[130];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__MonthScene_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__MonthScene_t qt_meta_stringdata_EventViews__MonthScene = {
    {
QT_MOC_LITERAL(0, 0, 22), // "EventViews::MonthScene"
QT_MOC_LITERAL(1, 23, 17), // "incidenceSelected"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 13), // "Akonadi::Item"
QT_MOC_LITERAL(4, 56, 9), // "incidence"
QT_MOC_LITERAL(5, 66, 24), // "showIncidencePopupSignal"
QT_MOC_LITERAL(6, 91, 14), // "newEventSignal"
QT_MOC_LITERAL(7, 106, 23) // "showNewEventPopupSignal"

    },
    "EventViews::MonthScene\0incidenceSelected\0"
    "\0Akonadi::Item\0incidence\0"
    "showIncidencePopupSignal\0newEventSignal\0"
    "showNewEventPopupSignal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__MonthScene[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   34,    2, 0x06 /* Public */,
       5,    2,   39,    2, 0x06 /* Public */,
       6,    0,   44,    2, 0x06 /* Public */,
       7,    0,   45,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QDate,    4,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QDate,    2,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void EventViews::MonthScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MonthScene *_t = static_cast<MonthScene *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->incidenceSelected((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 1: _t->showIncidencePopupSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 2: _t->newEventSignal(); break;
        case 3: _t->showNewEventPopupSignal(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MonthScene::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MonthScene::incidenceSelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MonthScene::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MonthScene::showIncidencePopupSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MonthScene::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MonthScene::newEventSignal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (MonthScene::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MonthScene::showNewEventPopupSignal)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject EventViews::MonthScene::staticMetaObject = {
    { &QGraphicsScene::staticMetaObject, qt_meta_stringdata_EventViews__MonthScene.data,
      qt_meta_data_EventViews__MonthScene,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::MonthScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::MonthScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__MonthScene.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int EventViews::MonthScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void EventViews::MonthScene::incidenceSelected(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void EventViews::MonthScene::showIncidencePopupSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void EventViews::MonthScene::newEventSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EventViews::MonthScene::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
struct qt_meta_stringdata_EventViews__MonthGraphicsView_t {
    QByteArrayData data[1];
    char stringdata0[30];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__MonthGraphicsView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__MonthGraphicsView_t qt_meta_stringdata_EventViews__MonthGraphicsView = {
    {
QT_MOC_LITERAL(0, 0, 29) // "EventViews::MonthGraphicsView"

    },
    "EventViews::MonthGraphicsView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__MonthGraphicsView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void EventViews::MonthGraphicsView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject EventViews::MonthGraphicsView::staticMetaObject = {
    { &QGraphicsView::staticMetaObject, qt_meta_stringdata_EventViews__MonthGraphicsView.data,
      qt_meta_data_EventViews__MonthGraphicsView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::MonthGraphicsView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::MonthGraphicsView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__MonthGraphicsView.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int EventViews::MonthGraphicsView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
