/****************************************************************************
** Meta object code from reading C++ file 'incidencetreemodel_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/todo/incidencetreemodel_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'incidencetreemodel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IncidenceTreeModel__Private_t {
    QByteArrayData data[20];
    char stringdata0[283];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IncidenceTreeModel__Private_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IncidenceTreeModel__Private_t qt_meta_stringdata_IncidenceTreeModel__Private = {
    {
QT_MOC_LITERAL(0, 0, 27), // "IncidenceTreeModel::Private"
QT_MOC_LITERAL(1, 28, 19), // "onHeaderDataChanged"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 15), // "Qt::Orientation"
QT_MOC_LITERAL(4, 65, 11), // "orientation"
QT_MOC_LITERAL(5, 77, 5), // "first"
QT_MOC_LITERAL(6, 83, 4), // "last"
QT_MOC_LITERAL(7, 88, 13), // "onDataChanged"
QT_MOC_LITERAL(8, 102, 5), // "begin"
QT_MOC_LITERAL(9, 108, 3), // "end"
QT_MOC_LITERAL(10, 112, 23), // "onRowsAboutToBeInserted"
QT_MOC_LITERAL(11, 136, 6), // "parent"
QT_MOC_LITERAL(12, 143, 14), // "onRowsInserted"
QT_MOC_LITERAL(13, 158, 22), // "onRowsAboutToBeRemoved"
QT_MOC_LITERAL(14, 181, 13), // "onRowsRemoved"
QT_MOC_LITERAL(15, 195, 11), // "onRowsMoved"
QT_MOC_LITERAL(16, 207, 21), // "onModelAboutToBeReset"
QT_MOC_LITERAL(17, 229, 12), // "onModelReset"
QT_MOC_LITERAL(18, 242, 24), // "onLayoutAboutToBeChanged"
QT_MOC_LITERAL(19, 267, 15) // "onLayoutChanged"

    },
    "IncidenceTreeModel::Private\0"
    "onHeaderDataChanged\0\0Qt::Orientation\0"
    "orientation\0first\0last\0onDataChanged\0"
    "begin\0end\0onRowsAboutToBeInserted\0"
    "parent\0onRowsInserted\0onRowsAboutToBeRemoved\0"
    "onRowsRemoved\0onRowsMoved\0"
    "onModelAboutToBeReset\0onModelReset\0"
    "onLayoutAboutToBeChanged\0onLayoutChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IncidenceTreeModel__Private[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    3,   69,    2, 0x08 /* Private */,
       7,    2,   76,    2, 0x08 /* Private */,
      10,    3,   81,    2, 0x08 /* Private */,
      12,    3,   88,    2, 0x08 /* Private */,
      13,    3,   95,    2, 0x08 /* Private */,
      14,    3,  102,    2, 0x08 /* Private */,
      15,    5,  109,    2, 0x08 /* Private */,
      16,    0,  120,    2, 0x08 /* Private */,
      17,    0,  121,    2, 0x08 /* Private */,
      18,    0,  122,    2, 0x08 /* Private */,
      19,    0,  123,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    4,    5,    6,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    8,    9,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   11,    8,    9,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   11,    8,    9,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   11,    8,    9,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   11,    8,    9,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int, QMetaType::QModelIndex, QMetaType::Int,    2,    2,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void IncidenceTreeModel::Private::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Private *_t = static_cast<Private *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onHeaderDataChanged((*reinterpret_cast< Qt::Orientation(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 1: _t->onDataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 2: _t->onRowsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->onRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->onRowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 5: _t->onRowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 6: _t->onRowsMoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 7: _t->onModelAboutToBeReset(); break;
        case 8: _t->onModelReset(); break;
        case 9: _t->onLayoutAboutToBeChanged(); break;
        case 10: _t->onLayoutChanged(); break;
        default: ;
        }
    }
}

const QMetaObject IncidenceTreeModel::Private::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_IncidenceTreeModel__Private.data,
      qt_meta_data_IncidenceTreeModel__Private,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *IncidenceTreeModel::Private::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceTreeModel::Private::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IncidenceTreeModel__Private.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int IncidenceTreeModel::Private::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
