/****************************************************************************
** Meta object code from reading C++ file 'todomodel_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/todo/todomodel_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'todomodel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TodoModel__Private_t {
    QByteArrayData data[26];
    char stringdata0[363];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TodoModel__Private_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TodoModel__Private_t qt_meta_stringdata_TodoModel__Private = {
    {
QT_MOC_LITERAL(0, 0, 18), // "TodoModel::Private"
QT_MOC_LITERAL(1, 19, 13), // "onDataChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 5), // "begin"
QT_MOC_LITERAL(4, 40, 3), // "end"
QT_MOC_LITERAL(5, 44, 19), // "onHeaderDataChanged"
QT_MOC_LITERAL(6, 64, 15), // "Qt::Orientation"
QT_MOC_LITERAL(7, 80, 11), // "orientation"
QT_MOC_LITERAL(8, 92, 5), // "first"
QT_MOC_LITERAL(9, 98, 4), // "last"
QT_MOC_LITERAL(10, 103, 23), // "onRowsAboutToBeInserted"
QT_MOC_LITERAL(11, 127, 6), // "parent"
QT_MOC_LITERAL(12, 134, 14), // "onRowsInserted"
QT_MOC_LITERAL(13, 149, 22), // "onRowsAboutToBeRemoved"
QT_MOC_LITERAL(14, 172, 13), // "onRowsRemoved"
QT_MOC_LITERAL(15, 186, 20), // "onRowsAboutToBeMoved"
QT_MOC_LITERAL(16, 207, 12), // "sourceParent"
QT_MOC_LITERAL(17, 220, 11), // "sourceStart"
QT_MOC_LITERAL(18, 232, 9), // "sourceEnd"
QT_MOC_LITERAL(19, 242, 17), // "destinationParent"
QT_MOC_LITERAL(20, 260, 14), // "destinationRow"
QT_MOC_LITERAL(21, 275, 11), // "onRowsMoved"
QT_MOC_LITERAL(22, 287, 21), // "onModelAboutToBeReset"
QT_MOC_LITERAL(23, 309, 12), // "onModelReset"
QT_MOC_LITERAL(24, 322, 24), // "onLayoutAboutToBeChanged"
QT_MOC_LITERAL(25, 347, 15) // "onLayoutChanged"

    },
    "TodoModel::Private\0onDataChanged\0\0"
    "begin\0end\0onHeaderDataChanged\0"
    "Qt::Orientation\0orientation\0first\0"
    "last\0onRowsAboutToBeInserted\0parent\0"
    "onRowsInserted\0onRowsAboutToBeRemoved\0"
    "onRowsRemoved\0onRowsAboutToBeMoved\0"
    "sourceParent\0sourceStart\0sourceEnd\0"
    "destinationParent\0destinationRow\0"
    "onRowsMoved\0onModelAboutToBeReset\0"
    "onModelReset\0onLayoutAboutToBeChanged\0"
    "onLayoutChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TodoModel__Private[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   74,    2, 0x08 /* Private */,
       5,    3,   79,    2, 0x08 /* Private */,
      10,    3,   86,    2, 0x08 /* Private */,
      12,    3,   93,    2, 0x08 /* Private */,
      13,    3,  100,    2, 0x08 /* Private */,
      14,    3,  107,    2, 0x08 /* Private */,
      15,    5,  114,    2, 0x08 /* Private */,
      21,    5,  125,    2, 0x08 /* Private */,
      22,    0,  136,    2, 0x08 /* Private */,
      23,    0,  137,    2, 0x08 /* Private */,
      24,    0,  138,    2, 0x08 /* Private */,
      25,    0,  139,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    3,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int, QMetaType::Int,    7,    8,    9,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   11,    3,    4,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   11,    3,    4,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   11,    3,    4,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   11,    3,    4,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int, QMetaType::QModelIndex, QMetaType::Int,   16,   17,   18,   19,   20,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int, QMetaType::QModelIndex, QMetaType::Int,    2,    2,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void TodoModel::Private::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Private *_t = static_cast<Private *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onDataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 1: _t->onHeaderDataChanged((*reinterpret_cast< Qt::Orientation(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 2: _t->onRowsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->onRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->onRowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 5: _t->onRowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 6: _t->onRowsAboutToBeMoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 7: _t->onRowsMoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 8: _t->onModelAboutToBeReset(); break;
        case 9: _t->onModelReset(); break;
        case 10: _t->onLayoutAboutToBeChanged(); break;
        case 11: _t->onLayoutChanged(); break;
        default: ;
        }
    }
}

const QMetaObject TodoModel::Private::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_TodoModel__Private.data,
      qt_meta_data_TodoModel__Private,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TodoModel::Private::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TodoModel::Private::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TodoModel__Private.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TodoModel::Private::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
