/****************************************************************************
** Meta object code from reading C++ file 'agendaview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/agenda/agendaview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agendaview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__EventIndicator_t {
    QByteArrayData data[1];
    char stringdata0[27];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__EventIndicator_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__EventIndicator_t qt_meta_stringdata_EventViews__EventIndicator = {
    {
QT_MOC_LITERAL(0, 0, 26) // "EventViews::EventIndicator"

    },
    "EventViews::EventIndicator"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__EventIndicator[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void EventViews::EventIndicator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject EventViews::EventIndicator::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_EventViews__EventIndicator.data,
      qt_meta_data_EventViews__EventIndicator,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::EventIndicator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::EventIndicator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__EventIndicator.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int EventViews::EventIndicator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_EventViews__AgendaView_t {
    QByteArrayData data[34];
    char stringdata0[582];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__AgendaView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__AgendaView_t qt_meta_stringdata_EventViews__AgendaView = {
    {
QT_MOC_LITERAL(0, 0, 22), // "EventViews::AgendaView"
QT_MOC_LITERAL(1, 23, 23), // "showNewEventPopupSignal"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 24), // "showIncidencePopupSignal"
QT_MOC_LITERAL(4, 73, 13), // "Akonadi::Item"
QT_MOC_LITERAL(5, 87, 20), // "zoomViewHorizontally"
QT_MOC_LITERAL(6, 108, 5), // "count"
QT_MOC_LITERAL(7, 114, 24), // "timeSpanSelectionChanged"
QT_MOC_LITERAL(8, 139, 10), // "updateView"
QT_MOC_LITERAL(9, 150, 12), // "updateConfig"
QT_MOC_LITERAL(10, 163, 21), // "slotIncidencesDropped"
QT_MOC_LITERAL(11, 185, 25), // "KCalCore::Incidence::List"
QT_MOC_LITERAL(12, 211, 10), // "incidences"
QT_MOC_LITERAL(13, 222, 11), // "QList<QUrl>"
QT_MOC_LITERAL(14, 234, 9), // "startDrag"
QT_MOC_LITERAL(15, 244, 24), // "KCalCore::Incidence::Ptr"
QT_MOC_LITERAL(16, 269, 23), // "updateEventIndicatorTop"
QT_MOC_LITERAL(17, 293, 4), // "newY"
QT_MOC_LITERAL(18, 298, 26), // "updateEventIndicatorBottom"
QT_MOC_LITERAL(19, 325, 19), // "newTimeSpanSelected"
QT_MOC_LITERAL(20, 345, 5), // "start"
QT_MOC_LITERAL(21, 351, 3), // "end"
QT_MOC_LITERAL(22, 355, 25), // "newTimeSpanSelectedAllDay"
QT_MOC_LITERAL(23, 381, 21), // "updateEventIndicators"
QT_MOC_LITERAL(24, 403, 29), // "scheduleUpdateEventIndicators"
QT_MOC_LITERAL(25, 433, 19), // "updateDayLabelSizes"
QT_MOC_LITERAL(26, 453, 12), // "alignAgendas"
QT_MOC_LITERAL(27, 466, 21), // "slotIncidenceSelected"
QT_MOC_LITERAL(28, 488, 9), // "incidence"
QT_MOC_LITERAL(29, 498, 4), // "date"
QT_MOC_LITERAL(30, 503, 22), // "slotShowIncidencePopup"
QT_MOC_LITERAL(31, 526, 17), // "slotEditIncidence"
QT_MOC_LITERAL(32, 544, 17), // "slotShowIncidence"
QT_MOC_LITERAL(33, 562, 19) // "slotDeleteIncidence"

    },
    "EventViews::AgendaView\0showNewEventPopupSignal\0"
    "\0showIncidencePopupSignal\0Akonadi::Item\0"
    "zoomViewHorizontally\0count\0"
    "timeSpanSelectionChanged\0updateView\0"
    "updateConfig\0slotIncidencesDropped\0"
    "KCalCore::Incidence::List\0incidences\0"
    "QList<QUrl>\0startDrag\0KCalCore::Incidence::Ptr\0"
    "updateEventIndicatorTop\0newY\0"
    "updateEventIndicatorBottom\0"
    "newTimeSpanSelected\0start\0end\0"
    "newTimeSpanSelectedAllDay\0"
    "updateEventIndicators\0"
    "scheduleUpdateEventIndicators\0"
    "updateDayLabelSizes\0alignAgendas\0"
    "slotIncidenceSelected\0incidence\0date\0"
    "slotShowIncidencePopup\0slotEditIncidence\0"
    "slotShowIncidence\0slotDeleteIncidence"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__AgendaView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  124,    2, 0x06 /* Public */,
       3,    2,  125,    2, 0x06 /* Public */,
       5,    2,  130,    2, 0x06 /* Public */,
       7,    0,  135,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,  136,    2, 0x0a /* Public */,
       9,    0,  137,    2, 0x0a /* Public */,
      10,    3,  138,    2, 0x0a /* Public */,
      10,    3,  145,    2, 0x0a /* Public */,
      14,    1,  152,    2, 0x0a /* Public */,
      16,    1,  155,    2, 0x09 /* Protected */,
      18,    1,  158,    2, 0x09 /* Protected */,
      19,    2,  161,    2, 0x09 /* Protected */,
      22,    2,  166,    2, 0x09 /* Protected */,
      23,    0,  171,    2, 0x09 /* Protected */,
      24,    0,  172,    2, 0x09 /* Protected */,
      25,    0,  173,    2, 0x09 /* Protected */,
      26,    0,  174,    2, 0x09 /* Protected */,
      27,    2,  175,    2, 0x08 /* Private */,
      30,    2,  180,    2, 0x08 /* Private */,
      31,    1,  185,    2, 0x08 /* Private */,
      32,    1,  188,    2, 0x08 /* Private */,
      33,    1,  191,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QDate,    2,    2,
    QMetaType::Void, QMetaType::QDate, QMetaType::Int,    2,    6,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11, QMetaType::QPoint, QMetaType::Bool,   12,    2,    2,
    QMetaType::Void, 0x80000000 | 13, QMetaType::QPoint, QMetaType::Bool,   12,    2,    2,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::QPoint, QMetaType::QPoint,   20,   21,
    QMetaType::Void, QMetaType::QPoint, QMetaType::QPoint,   20,   21,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15, QMetaType::QDate,   28,   29,
    QMetaType::Void, 0x80000000 | 15, QMetaType::QDate,   28,   29,
    QMetaType::Void, 0x80000000 | 15,   28,
    QMetaType::Void, 0x80000000 | 15,   28,
    QMetaType::Void, 0x80000000 | 15,   28,

       0        // eod
};

void EventViews::AgendaView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AgendaView *_t = static_cast<AgendaView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showNewEventPopupSignal(); break;
        case 1: _t->showIncidencePopupSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 2: _t->zoomViewHorizontally((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->timeSpanSelectionChanged(); break;
        case 4: _t->updateView(); break;
        case 5: _t->updateConfig(); break;
        case 6: _t->slotIncidencesDropped((*reinterpret_cast< const KCalCore::Incidence::List(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 7: _t->slotIncidencesDropped((*reinterpret_cast< const QList<QUrl>(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 8: _t->startDrag((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1]))); break;
        case 9: _t->updateEventIndicatorTop((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->updateEventIndicatorBottom((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->newTimeSpanSelected((*reinterpret_cast< const QPoint(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 12: _t->newTimeSpanSelectedAllDay((*reinterpret_cast< const QPoint(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 13: _t->updateEventIndicators(); break;
        case 14: _t->scheduleUpdateEventIndicators(); break;
        case 15: _t->updateDayLabelSizes(); break;
        case 16: _t->alignAgendas(); break;
        case 17: _t->slotIncidenceSelected((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 18: _t->slotShowIncidencePopup((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 19: _t->slotEditIncidence((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1]))); break;
        case 20: _t->slotShowIncidence((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1]))); break;
        case 21: _t->slotDeleteIncidence((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (AgendaView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AgendaView::showNewEventPopupSignal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (AgendaView::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AgendaView::showIncidencePopupSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (AgendaView::*_t)(const QDate & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AgendaView::zoomViewHorizontally)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (AgendaView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AgendaView::timeSpanSelectionChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject EventViews::AgendaView::staticMetaObject = {
    { &EventView::staticMetaObject, qt_meta_stringdata_EventViews__AgendaView.data,
      qt_meta_data_EventViews__AgendaView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::AgendaView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::AgendaView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__AgendaView.stringdata0))
        return static_cast<void*>(this);
    return EventView::qt_metacast(_clname);
}

int EventViews::AgendaView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void EventViews::AgendaView::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::AgendaView::showIncidencePopupSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void EventViews::AgendaView::zoomViewHorizontally(const QDate & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void EventViews::AgendaView::timeSpanSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
