/****************************************************************************
** Meta object code from reading C++ file 'eventview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/eventview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'eventview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__EventView_t {
    QByteArrayData data[52];
    char stringdata0[806];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__EventView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__EventView_t qt_meta_stringdata_EventViews__EventView = {
    {
QT_MOC_LITERAL(0, 0, 21), // "EventViews::EventView"
QT_MOC_LITERAL(1, 22, 13), // "datesSelected"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 18), // "KCalCore::DateList"
QT_MOC_LITERAL(4, 56, 8), // "datelist"
QT_MOC_LITERAL(5, 65, 12), // "shiftedEvent"
QT_MOC_LITERAL(6, 78, 7), // "olddate"
QT_MOC_LITERAL(7, 86, 7), // "newdate"
QT_MOC_LITERAL(8, 94, 17), // "incidenceSelected"
QT_MOC_LITERAL(9, 112, 13), // "Akonadi::Item"
QT_MOC_LITERAL(10, 126, 19), // "showIncidenceSignal"
QT_MOC_LITERAL(11, 146, 19), // "editIncidenceSignal"
QT_MOC_LITERAL(12, 166, 21), // "deleteIncidenceSignal"
QT_MOC_LITERAL(13, 188, 18), // "cutIncidenceSignal"
QT_MOC_LITERAL(14, 207, 19), // "copyIncidenceSignal"
QT_MOC_LITERAL(15, 227, 20), // "pasteIncidenceSignal"
QT_MOC_LITERAL(16, 248, 17), // "toggleAlarmSignal"
QT_MOC_LITERAL(17, 266, 25), // "toggleTodoCompletedSignal"
QT_MOC_LITERAL(18, 292, 29), // "copyIncidenceToResourceSignal"
QT_MOC_LITERAL(19, 322, 19), // "Akonadi::Collection"
QT_MOC_LITERAL(20, 342, 29), // "moveIncidenceToResourceSignal"
QT_MOC_LITERAL(21, 372, 27), // "dissociateOccurrencesSignal"
QT_MOC_LITERAL(22, 400, 14), // "newEventSignal"
QT_MOC_LITERAL(23, 415, 13), // "newTodoSignal"
QT_MOC_LITERAL(24, 429, 16), // "newSubTodoSignal"
QT_MOC_LITERAL(25, 446, 16), // "newJournalSignal"
QT_MOC_LITERAL(26, 463, 14), // "showIncidences"
QT_MOC_LITERAL(27, 478, 19), // "Akonadi::Item::List"
QT_MOC_LITERAL(28, 498, 13), // "incidenceList"
QT_MOC_LITERAL(29, 512, 4), // "date"
QT_MOC_LITERAL(30, 517, 10), // "updateView"
QT_MOC_LITERAL(31, 528, 9), // "dayPassed"
QT_MOC_LITERAL(32, 538, 19), // "setIncidenceChanger"
QT_MOC_LITERAL(33, 558, 26), // "Akonadi::IncidenceChanger*"
QT_MOC_LITERAL(34, 585, 7), // "changer"
QT_MOC_LITERAL(35, 593, 9), // "flushView"
QT_MOC_LITERAL(36, 603, 12), // "updateConfig"
QT_MOC_LITERAL(37, 616, 14), // "clearSelection"
QT_MOC_LITERAL(38, 631, 17), // "eventDurationHint"
QT_MOC_LITERAL(39, 649, 10), // "QDateTime&"
QT_MOC_LITERAL(40, 660, 7), // "startDt"
QT_MOC_LITERAL(41, 668, 5), // "endDt"
QT_MOC_LITERAL(42, 674, 5), // "bool&"
QT_MOC_LITERAL(43, 680, 6), // "allDay"
QT_MOC_LITERAL(44, 687, 12), // "focusChanged"
QT_MOC_LITERAL(45, 700, 8), // "QWidget*"
QT_MOC_LITERAL(46, 709, 13), // "defaultAction"
QT_MOC_LITERAL(47, 723, 9), // "incidence"
QT_MOC_LITERAL(48, 733, 16), // "setHolidayRegion"
QT_MOC_LITERAL(49, 750, 27), // "KHolidays::HolidayRegionPtr"
QT_MOC_LITERAL(50, 778, 13), // "holidayRegion"
QT_MOC_LITERAL(51, 792, 13) // "calendarReset"

    },
    "EventViews::EventView\0datesSelected\0"
    "\0KCalCore::DateList\0datelist\0shiftedEvent\0"
    "olddate\0newdate\0incidenceSelected\0"
    "Akonadi::Item\0showIncidenceSignal\0"
    "editIncidenceSignal\0deleteIncidenceSignal\0"
    "cutIncidenceSignal\0copyIncidenceSignal\0"
    "pasteIncidenceSignal\0toggleAlarmSignal\0"
    "toggleTodoCompletedSignal\0"
    "copyIncidenceToResourceSignal\0"
    "Akonadi::Collection\0moveIncidenceToResourceSignal\0"
    "dissociateOccurrencesSignal\0newEventSignal\0"
    "newTodoSignal\0newSubTodoSignal\0"
    "newJournalSignal\0showIncidences\0"
    "Akonadi::Item::List\0incidenceList\0"
    "date\0updateView\0dayPassed\0setIncidenceChanger\0"
    "Akonadi::IncidenceChanger*\0changer\0"
    "flushView\0updateConfig\0clearSelection\0"
    "eventDurationHint\0QDateTime&\0startDt\0"
    "endDt\0bool&\0allDay\0focusChanged\0"
    "QWidget*\0defaultAction\0incidence\0"
    "setHolidayRegion\0KHolidays::HolidayRegionPtr\0"
    "holidayRegion\0calendarReset"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__EventView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      33,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      21,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  179,    2, 0x06 /* Public */,
       5,    2,  182,    2, 0x06 /* Public */,
       8,    2,  187,    2, 0x06 /* Public */,
      10,    1,  192,    2, 0x06 /* Public */,
      11,    1,  195,    2, 0x06 /* Public */,
      12,    1,  198,    2, 0x06 /* Public */,
      13,    1,  201,    2, 0x06 /* Public */,
      14,    1,  204,    2, 0x06 /* Public */,
      15,    0,  207,    2, 0x06 /* Public */,
      16,    1,  208,    2, 0x06 /* Public */,
      17,    1,  211,    2, 0x06 /* Public */,
      18,    2,  214,    2, 0x06 /* Public */,
      20,    2,  219,    2, 0x06 /* Public */,
      21,    2,  224,    2, 0x06 /* Public */,
      22,    0,  229,    2, 0x06 /* Public */,
      22,    1,  230,    2, 0x06 /* Public */,
      22,    1,  233,    2, 0x06 /* Public */,
      22,    2,  236,    2, 0x06 /* Public */,
      23,    1,  241,    2, 0x06 /* Public */,
      24,    1,  244,    2, 0x06 /* Public */,
      25,    1,  247,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      26,    2,  250,    2, 0x0a /* Public */,
      30,    0,  255,    2, 0x0a /* Public */,
      31,    1,  256,    2, 0x0a /* Public */,
      32,    1,  259,    2, 0x0a /* Public */,
      35,    0,  262,    2, 0x0a /* Public */,
      36,    0,  263,    2, 0x0a /* Public */,
      37,    0,  264,    2, 0x0a /* Public */,
      38,    3,  265,    2, 0x0a /* Public */,
      44,    2,  272,    2, 0x0a /* Public */,
      46,    1,  277,    2, 0x0a /* Public */,
      48,    1,  280,    2, 0x0a /* Public */,
      51,    0,  283,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate,    6,    7,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QDate,    2,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 19,    2,    2,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 19,    2,    2,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QDate,    2,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QDate,    2,
    QMetaType::Void, QMetaType::QDateTime,    2,
    QMetaType::Void, QMetaType::QDateTime, QMetaType::QDateTime,    2,    2,
    QMetaType::Void, QMetaType::QDate,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, QMetaType::QDate,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 27, QMetaType::QDate,   28,   29,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QDate,    2,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool, 0x80000000 | 39, 0x80000000 | 39, 0x80000000 | 42,   40,   41,   43,
    QMetaType::Void, 0x80000000 | 45, 0x80000000 | 45,    2,    2,
    QMetaType::Void, 0x80000000 | 9,   47,
    QMetaType::Void, 0x80000000 | 49,   50,
    QMetaType::Void,

       0        // eod
};

void EventViews::EventView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        EventView *_t = static_cast<EventView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->datesSelected((*reinterpret_cast< const KCalCore::DateList(*)>(_a[1]))); break;
        case 1: _t->shiftedEvent((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 2: _t->incidenceSelected((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 3: _t->showIncidenceSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 4: _t->editIncidenceSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 5: _t->deleteIncidenceSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 6: _t->cutIncidenceSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 7: _t->copyIncidenceSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 8: _t->pasteIncidenceSignal(); break;
        case 9: _t->toggleAlarmSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 10: _t->toggleTodoCompletedSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 11: _t->copyIncidenceToResourceSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const Akonadi::Collection(*)>(_a[2]))); break;
        case 12: _t->moveIncidenceToResourceSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const Akonadi::Collection(*)>(_a[2]))); break;
        case 13: _t->dissociateOccurrencesSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 14: _t->newEventSignal(); break;
        case 15: _t->newEventSignal((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 16: _t->newEventSignal((*reinterpret_cast< const QDateTime(*)>(_a[1]))); break;
        case 17: _t->newEventSignal((*reinterpret_cast< const QDateTime(*)>(_a[1])),(*reinterpret_cast< const QDateTime(*)>(_a[2]))); break;
        case 18: _t->newTodoSignal((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 19: _t->newSubTodoSignal((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 20: _t->newJournalSignal((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 21: _t->showIncidences((*reinterpret_cast< const Akonadi::Item::List(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 22: _t->updateView(); break;
        case 23: _t->dayPassed((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 24: _t->setIncidenceChanger((*reinterpret_cast< Akonadi::IncidenceChanger*(*)>(_a[1]))); break;
        case 25: _t->flushView(); break;
        case 26: _t->updateConfig(); break;
        case 27: _t->clearSelection(); break;
        case 28: { bool _r = _t->eventDurationHint((*reinterpret_cast< QDateTime(*)>(_a[1])),(*reinterpret_cast< QDateTime(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->focusChanged((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 30: _t->defaultAction((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 31: _t->setHolidayRegion((*reinterpret_cast< const KHolidays::HolidayRegionPtr(*)>(_a[1]))); break;
        case 32: _t->calendarReset(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Collection >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Collection >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item::List >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (EventView::*_t)(const KCalCore::DateList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::datesSelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const QDate & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::shiftedEvent)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & , const QDate );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::incidenceSelected)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::showIncidenceSignal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::editIncidenceSignal)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::deleteIncidenceSignal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::cutIncidenceSignal)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::copyIncidenceSignal)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (EventView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::pasteIncidenceSignal)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::toggleAlarmSignal)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::toggleTodoCompletedSignal)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & , const Akonadi::Collection & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::copyIncidenceToResourceSignal)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & , const Akonadi::Collection & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::moveIncidenceToResourceSignal)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::dissociateOccurrencesSignal)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (EventView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::newEventSignal)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::newEventSignal)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const QDateTime & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::newEventSignal)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const QDateTime & , const QDateTime & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::newEventSignal)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::newTodoSignal)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::newSubTodoSignal)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (EventView::*_t)(const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventView::newJournalSignal)) {
                *result = 20;
                return;
            }
        }
    }
}

const QMetaObject EventViews::EventView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_EventViews__EventView.data,
      qt_meta_data_EventViews__EventView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::EventView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::EventView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__EventView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int EventViews::EventView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void EventViews::EventView::datesSelected(const KCalCore::DateList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void EventViews::EventView::shiftedEvent(const QDate & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void EventViews::EventView::incidenceSelected(const Akonadi::Item & _t1, const QDate _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void EventViews::EventView::showIncidenceSignal(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void EventViews::EventView::editIncidenceSignal(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void EventViews::EventView::deleteIncidenceSignal(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void EventViews::EventView::cutIncidenceSignal(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void EventViews::EventView::copyIncidenceSignal(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void EventViews::EventView::pasteIncidenceSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void EventViews::EventView::toggleAlarmSignal(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void EventViews::EventView::toggleTodoCompletedSignal(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void EventViews::EventView::copyIncidenceToResourceSignal(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void EventViews::EventView::moveIncidenceToResourceSignal(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void EventViews::EventView::dissociateOccurrencesSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void EventViews::EventView::newEventSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void EventViews::EventView::newEventSignal(const QDate & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void EventViews::EventView::newEventSignal(const QDateTime & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void EventViews::EventView::newEventSignal(const QDateTime & _t1, const QDateTime & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void EventViews::EventView::newTodoSignal(const QDate & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void EventViews::EventView::newSubTodoSignal(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void EventViews::EventView::newJournalSignal(const QDate & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
