/****************************************************************************
** Meta object code from reading C++ file 'agenda.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/agenda/agenda.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agenda.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__MarcusBains_t {
    QByteArrayData data[3];
    char stringdata0[40];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__MarcusBains_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__MarcusBains_t qt_meta_stringdata_EventViews__MarcusBains = {
    {
QT_MOC_LITERAL(0, 0, 23), // "EventViews::MarcusBains"
QT_MOC_LITERAL(1, 24, 14), // "updateLocation"
QT_MOC_LITERAL(2, 39, 0) // ""

    },
    "EventViews::MarcusBains\0updateLocation\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__MarcusBains[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void EventViews::MarcusBains::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MarcusBains *_t = static_cast<MarcusBains *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateLocation(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject EventViews::MarcusBains::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_EventViews__MarcusBains.data,
      qt_meta_data_EventViews__MarcusBains,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::MarcusBains::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::MarcusBains::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__MarcusBains.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int EventViews::MarcusBains::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_EventViews__Agenda_t {
    QByteArrayData data[45];
    char stringdata0[671];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__Agenda_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__Agenda_t qt_meta_stringdata_EventViews__Agenda = {
    {
QT_MOC_LITERAL(0, 0, 18), // "EventViews::Agenda"
QT_MOC_LITERAL(1, 19, 14), // "newEventSignal"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 17), // "newTimeSpanSignal"
QT_MOC_LITERAL(4, 53, 20), // "newStartSelectSignal"
QT_MOC_LITERAL(5, 74, 19), // "showIncidenceSignal"
QT_MOC_LITERAL(6, 94, 24), // "KCalCore::Incidence::Ptr"
QT_MOC_LITERAL(7, 119, 19), // "editIncidenceSignal"
QT_MOC_LITERAL(8, 139, 21), // "deleteIncidenceSignal"
QT_MOC_LITERAL(9, 161, 24), // "showIncidencePopupSignal"
QT_MOC_LITERAL(10, 186, 23), // "showNewEventPopupSignal"
QT_MOC_LITERAL(11, 210, 17), // "incidenceSelected"
QT_MOC_LITERAL(12, 228, 13), // "lowerYChanged"
QT_MOC_LITERAL(13, 242, 13), // "upperYChanged"
QT_MOC_LITERAL(14, 256, 15), // "startDragSignal"
QT_MOC_LITERAL(15, 272, 17), // "droppedIncidences"
QT_MOC_LITERAL(16, 290, 25), // "KCalCore::Incidence::List"
QT_MOC_LITERAL(17, 316, 4), // "gpos"
QT_MOC_LITERAL(18, 321, 6), // "allDay"
QT_MOC_LITERAL(19, 328, 11), // "QList<QUrl>"
QT_MOC_LITERAL(20, 340, 18), // "enableAgendaUpdate"
QT_MOC_LITERAL(21, 359, 6), // "enable"
QT_MOC_LITERAL(22, 366, 8), // "zoomView"
QT_MOC_LITERAL(23, 375, 5), // "delta"
QT_MOC_LITERAL(24, 381, 3), // "pos"
QT_MOC_LITERAL(25, 385, 15), // "Qt::Orientation"
QT_MOC_LITERAL(26, 401, 14), // "mousePosSignal"
QT_MOC_LITERAL(27, 416, 11), // "enterAgenda"
QT_MOC_LITERAL(28, 428, 11), // "leaveAgenda"
QT_MOC_LITERAL(29, 440, 19), // "gridSpacingYChanged"
QT_MOC_LITERAL(30, 460, 8), // "scrollUp"
QT_MOC_LITERAL(31, 469, 10), // "scrollDown"
QT_MOC_LITERAL(32, 480, 21), // "checkScrollBoundaries"
QT_MOC_LITERAL(33, 502, 12), // "deselectItem"
QT_MOC_LITERAL(34, 515, 14), // "clearSelection"
QT_MOC_LITERAL(35, 530, 10), // "selectItem"
QT_MOC_LITERAL(36, 541, 16), // "AgendaItem::QPtr"
QT_MOC_LITERAL(37, 558, 20), // "selectIncidenceByUid"
QT_MOC_LITERAL(38, 579, 2), // "id"
QT_MOC_LITERAL(39, 582, 13), // "Akonadi::Item"
QT_MOC_LITERAL(40, 596, 4), // "item"
QT_MOC_LITERAL(41, 601, 16), // "removeAgendaItem"
QT_MOC_LITERAL(42, 618, 14), // "showAgendaItem"
QT_MOC_LITERAL(43, 633, 19), // "deleteItemsToDelete"
QT_MOC_LITERAL(44, 653, 17) // "resizeAllContents"

    },
    "EventViews::Agenda\0newEventSignal\0\0"
    "newTimeSpanSignal\0newStartSelectSignal\0"
    "showIncidenceSignal\0KCalCore::Incidence::Ptr\0"
    "editIncidenceSignal\0deleteIncidenceSignal\0"
    "showIncidencePopupSignal\0"
    "showNewEventPopupSignal\0incidenceSelected\0"
    "lowerYChanged\0upperYChanged\0startDragSignal\0"
    "droppedIncidences\0KCalCore::Incidence::List\0"
    "gpos\0allDay\0QList<QUrl>\0enableAgendaUpdate\0"
    "enable\0zoomView\0delta\0pos\0Qt::Orientation\0"
    "mousePosSignal\0enterAgenda\0leaveAgenda\0"
    "gridSpacingYChanged\0scrollUp\0scrollDown\0"
    "checkScrollBoundaries\0deselectItem\0"
    "clearSelection\0selectItem\0AgendaItem::QPtr\0"
    "selectIncidenceByUid\0id\0Akonadi::Item\0"
    "item\0removeAgendaItem\0showAgendaItem\0"
    "deleteItemsToDelete\0resizeAllContents"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__Agenda[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      32,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      20,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  174,    2, 0x06 /* Public */,
       3,    2,  175,    2, 0x06 /* Public */,
       4,    0,  180,    2, 0x06 /* Public */,
       5,    1,  181,    2, 0x06 /* Public */,
       7,    1,  184,    2, 0x06 /* Public */,
       8,    1,  187,    2, 0x06 /* Public */,
       9,    2,  190,    2, 0x06 /* Public */,
      10,    0,  195,    2, 0x06 /* Public */,
      11,    2,  196,    2, 0x06 /* Public */,
      12,    1,  201,    2, 0x06 /* Public */,
      13,    1,  204,    2, 0x06 /* Public */,
      14,    1,  207,    2, 0x06 /* Public */,
      15,    3,  210,    2, 0x06 /* Public */,
      15,    3,  217,    2, 0x06 /* Public */,
      20,    1,  224,    2, 0x06 /* Public */,
      22,    3,  227,    2, 0x06 /* Public */,
      26,    1,  234,    2, 0x06 /* Public */,
      27,    0,  237,    2, 0x06 /* Public */,
      28,    0,  238,    2, 0x06 /* Public */,
      29,    1,  239,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      30,    0,  242,    2, 0x0a /* Public */,
      31,    0,  243,    2, 0x0a /* Public */,
      32,    1,  244,    2, 0x0a /* Public */,
      33,    0,  247,    2, 0x0a /* Public */,
      34,    0,  248,    2, 0x0a /* Public */,
      35,    1,  249,    2, 0x0a /* Public */,
      37,    1,  252,    2, 0x0a /* Public */,
      35,    1,  255,    2, 0x0a /* Public */,
      41,    1,  258,    2, 0x0a /* Public */,
      42,    1,  261,    2, 0x0a /* Public */,
      43,    0,  264,    2, 0x09 /* Protected */,
      44,    0,  265,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint, QMetaType::QPoint,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QDate,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QDate,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QPoint, QMetaType::Bool,    2,   17,   18,
    QMetaType::Void, 0x80000000 | 19, QMetaType::QPoint, QMetaType::Bool,    2,   17,   18,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void, QMetaType::Int, QMetaType::QPoint, 0x80000000 | 25,   23,   24,    2,
    QMetaType::Void, QMetaType::QPoint,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Double,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 36,    2,
    QMetaType::Void, QMetaType::QString,   38,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Bool, 0x80000000 | 36,   40,
    QMetaType::Void, 0x80000000 | 36,   40,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void EventViews::Agenda::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Agenda *_t = static_cast<Agenda *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newEventSignal(); break;
        case 1: _t->newTimeSpanSignal((*reinterpret_cast< const QPoint(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 2: _t->newStartSelectSignal(); break;
        case 3: _t->showIncidenceSignal((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1]))); break;
        case 4: _t->editIncidenceSignal((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1]))); break;
        case 5: _t->deleteIncidenceSignal((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1]))); break;
        case 6: _t->showIncidencePopupSignal((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 7: _t->showNewEventPopupSignal(); break;
        case 8: _t->incidenceSelected((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 9: _t->lowerYChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->upperYChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->startDragSignal((*reinterpret_cast< const KCalCore::Incidence::Ptr(*)>(_a[1]))); break;
        case 12: _t->droppedIncidences((*reinterpret_cast< const KCalCore::Incidence::List(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 13: _t->droppedIncidences((*reinterpret_cast< const QList<QUrl>(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 14: _t->enableAgendaUpdate((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->zoomView((*reinterpret_cast< const int(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2])),(*reinterpret_cast< const Qt::Orientation(*)>(_a[3]))); break;
        case 16: _t->mousePosSignal((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 17: _t->enterAgenda(); break;
        case 18: _t->leaveAgenda(); break;
        case 19: _t->gridSpacingYChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 20: _t->scrollUp(); break;
        case 21: _t->scrollDown(); break;
        case 22: _t->checkScrollBoundaries((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->deselectItem(); break;
        case 24: _t->clearSelection(); break;
        case 25: _t->selectItem((*reinterpret_cast< const AgendaItem::QPtr(*)>(_a[1]))); break;
        case 26: _t->selectIncidenceByUid((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->selectItem((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 28: { bool _r = _t->removeAgendaItem((*reinterpret_cast< const AgendaItem::QPtr(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->showAgendaItem((*reinterpret_cast< const AgendaItem::QPtr(*)>(_a[1]))); break;
        case 30: _t->deleteItemsToDelete(); break;
        case 31: _t->resizeAllContents(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Agenda::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::newEventSignal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const QPoint & , const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::newTimeSpanSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::newStartSelectSignal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const KCalCore::Incidence::Ptr & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::showIncidenceSignal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const KCalCore::Incidence::Ptr & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::editIncidenceSignal)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const KCalCore::Incidence::Ptr & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::deleteIncidenceSignal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const KCalCore::Incidence::Ptr & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::showIncidencePopupSignal)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::showNewEventPopupSignal)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const KCalCore::Incidence::Ptr & , const QDate & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::incidenceSelected)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::lowerYChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::upperYChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const KCalCore::Incidence::Ptr & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::startDragSignal)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const KCalCore::Incidence::List & , const QPoint & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::droppedIncidences)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const QList<QUrl> & , const QPoint & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::droppedIncidences)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::enableAgendaUpdate)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const int , const QPoint & , const Qt::Orientation );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::zoomView)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::mousePosSignal)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::enterAgenda)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::leaveAgenda)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (Agenda::*_t)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Agenda::gridSpacingYChanged)) {
                *result = 19;
                return;
            }
        }
    }
}

const QMetaObject EventViews::Agenda::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_EventViews__Agenda.data,
      qt_meta_data_EventViews__Agenda,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::Agenda::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::Agenda::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__Agenda.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int EventViews::Agenda::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void EventViews::Agenda::newEventSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::Agenda::newTimeSpanSignal(const QPoint & _t1, const QPoint & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void EventViews::Agenda::newStartSelectSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EventViews::Agenda::showIncidenceSignal(const KCalCore::Incidence::Ptr & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void EventViews::Agenda::editIncidenceSignal(const KCalCore::Incidence::Ptr & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void EventViews::Agenda::deleteIncidenceSignal(const KCalCore::Incidence::Ptr & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void EventViews::Agenda::showIncidencePopupSignal(const KCalCore::Incidence::Ptr & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void EventViews::Agenda::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void EventViews::Agenda::incidenceSelected(const KCalCore::Incidence::Ptr & _t1, const QDate & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void EventViews::Agenda::lowerYChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void EventViews::Agenda::upperYChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void EventViews::Agenda::startDragSignal(const KCalCore::Incidence::Ptr & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void EventViews::Agenda::droppedIncidences(const KCalCore::Incidence::List & _t1, const QPoint & _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void EventViews::Agenda::droppedIncidences(const QList<QUrl> & _t1, const QPoint & _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void EventViews::Agenda::enableAgendaUpdate(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void EventViews::Agenda::zoomView(const int _t1, const QPoint & _t2, const Qt::Orientation _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void EventViews::Agenda::mousePosSignal(const QPoint & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void EventViews::Agenda::enterAgenda()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void EventViews::Agenda::leaveAgenda()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void EventViews::Agenda::gridSpacingYChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}
struct qt_meta_stringdata_EventViews__AgendaScrollArea_t {
    QByteArrayData data[1];
    char stringdata0[29];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__AgendaScrollArea_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__AgendaScrollArea_t qt_meta_stringdata_EventViews__AgendaScrollArea = {
    {
QT_MOC_LITERAL(0, 0, 28) // "EventViews::AgendaScrollArea"

    },
    "EventViews::AgendaScrollArea"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__AgendaScrollArea[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void EventViews::AgendaScrollArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject EventViews::AgendaScrollArea::staticMetaObject = {
    { &QScrollArea::staticMetaObject, qt_meta_stringdata_EventViews__AgendaScrollArea.data,
      qt_meta_data_EventViews__AgendaScrollArea,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::AgendaScrollArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::AgendaScrollArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__AgendaScrollArea.stringdata0))
        return static_cast<void*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int EventViews::AgendaScrollArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
