/****************************************************************************
** Meta object code from reading C++ file 'todoview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/todo/todoview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'todoview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__TodoView_t {
    QByteArrayData data[71];
    char stringdata0[932];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__TodoView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__TodoView_t qt_meta_stringdata_EventViews__TodoView = {
    {
QT_MOC_LITERAL(0, 0, 20), // "EventViews::TodoView"
QT_MOC_LITERAL(1, 21, 20), // "purgeCompletedSignal"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 15), // "unSubTodoSignal"
QT_MOC_LITERAL(4, 59, 18), // "unAllSubTodoSignal"
QT_MOC_LITERAL(5, 78, 13), // "configChanged"
QT_MOC_LITERAL(6, 92, 15), // "fullViewChanged"
QT_MOC_LITERAL(7, 108, 7), // "enabled"
QT_MOC_LITERAL(8, 116, 16), // "printPreviewTodo"
QT_MOC_LITERAL(9, 133, 9), // "printTodo"
QT_MOC_LITERAL(10, 143, 10), // "createNote"
QT_MOC_LITERAL(11, 154, 13), // "Akonadi::Item"
QT_MOC_LITERAL(12, 168, 4), // "item"
QT_MOC_LITERAL(13, 173, 11), // "createEvent"
QT_MOC_LITERAL(14, 185, 19), // "setIncidenceChanger"
QT_MOC_LITERAL(15, 205, 26), // "Akonadi::IncidenceChanger*"
QT_MOC_LITERAL(16, 232, 7), // "changer"
QT_MOC_LITERAL(17, 240, 9), // "showDates"
QT_MOC_LITERAL(18, 250, 5), // "start"
QT_MOC_LITERAL(19, 256, 3), // "end"
QT_MOC_LITERAL(20, 260, 14), // "preferredMonth"
QT_MOC_LITERAL(21, 275, 14), // "showIncidences"
QT_MOC_LITERAL(22, 290, 19), // "Akonadi::Item::List"
QT_MOC_LITERAL(23, 310, 13), // "incidenceList"
QT_MOC_LITERAL(24, 324, 4), // "date"
QT_MOC_LITERAL(25, 329, 10), // "updateView"
QT_MOC_LITERAL(26, 340, 22), // "changeIncidenceDisplay"
QT_MOC_LITERAL(27, 363, 9), // "incidence"
QT_MOC_LITERAL(28, 373, 37), // "Akonadi::IncidenceChanger::Ch..."
QT_MOC_LITERAL(29, 411, 10), // "changeType"
QT_MOC_LITERAL(30, 422, 12), // "updateConfig"
QT_MOC_LITERAL(31, 435, 14), // "clearSelection"
QT_MOC_LITERAL(32, 450, 11), // "expandIndex"
QT_MOC_LITERAL(33, 462, 5), // "index"
QT_MOC_LITERAL(34, 468, 16), // "restoreViewState"
QT_MOC_LITERAL(35, 485, 13), // "saveViewState"
QT_MOC_LITERAL(36, 499, 11), // "resizeEvent"
QT_MOC_LITERAL(37, 511, 13), // "QResizeEvent*"
QT_MOC_LITERAL(38, 525, 12), // "addQuickTodo"
QT_MOC_LITERAL(39, 538, 21), // "Qt::KeyboardModifiers"
QT_MOC_LITERAL(40, 560, 8), // "modifier"
QT_MOC_LITERAL(41, 569, 11), // "contextMenu"
QT_MOC_LITERAL(42, 581, 3), // "pos"
QT_MOC_LITERAL(43, 585, 16), // "selectionChanged"
QT_MOC_LITERAL(44, 602, 14), // "QItemSelection"
QT_MOC_LITERAL(45, 617, 8), // "selected"
QT_MOC_LITERAL(46, 626, 10), // "deselected"
QT_MOC_LITERAL(47, 637, 8), // "showTodo"
QT_MOC_LITERAL(48, 646, 8), // "editTodo"
QT_MOC_LITERAL(49, 655, 10), // "deleteTodo"
QT_MOC_LITERAL(50, 666, 7), // "newTodo"
QT_MOC_LITERAL(51, 674, 10), // "newSubTodo"
QT_MOC_LITERAL(52, 685, 14), // "copyTodoToDate"
QT_MOC_LITERAL(53, 700, 21), // "scheduleResizeColumns"
QT_MOC_LITERAL(54, 722, 13), // "resizeColumns"
QT_MOC_LITERAL(55, 736, 17), // "itemDoubleClicked"
QT_MOC_LITERAL(56, 754, 10), // "setNewDate"
QT_MOC_LITERAL(57, 765, 16), // "setNewPercentage"
QT_MOC_LITERAL(58, 782, 8), // "QAction*"
QT_MOC_LITERAL(59, 791, 6), // "action"
QT_MOC_LITERAL(60, 798, 14), // "setNewPriority"
QT_MOC_LITERAL(61, 813, 17), // "changedCategories"
QT_MOC_LITERAL(62, 831, 11), // "setFullView"
QT_MOC_LITERAL(63, 843, 8), // "fullView"
QT_MOC_LITERAL(64, 852, 11), // "setFlatView"
QT_MOC_LITERAL(65, 864, 8), // "flatView"
QT_MOC_LITERAL(66, 873, 16), // "notifyOtherViews"
QT_MOC_LITERAL(67, 890, 14), // "onRowsInserted"
QT_MOC_LITERAL(68, 905, 6), // "parent"
QT_MOC_LITERAL(69, 912, 13), // "onTagsFetched"
QT_MOC_LITERAL(70, 926, 5) // "KJob*"

    },
    "EventViews::TodoView\0purgeCompletedSignal\0"
    "\0unSubTodoSignal\0unAllSubTodoSignal\0"
    "configChanged\0fullViewChanged\0enabled\0"
    "printPreviewTodo\0printTodo\0createNote\0"
    "Akonadi::Item\0item\0createEvent\0"
    "setIncidenceChanger\0Akonadi::IncidenceChanger*\0"
    "changer\0showDates\0start\0end\0preferredMonth\0"
    "showIncidences\0Akonadi::Item::List\0"
    "incidenceList\0date\0updateView\0"
    "changeIncidenceDisplay\0incidence\0"
    "Akonadi::IncidenceChanger::ChangeType\0"
    "changeType\0updateConfig\0clearSelection\0"
    "expandIndex\0index\0restoreViewState\0"
    "saveViewState\0resizeEvent\0QResizeEvent*\0"
    "addQuickTodo\0Qt::KeyboardModifiers\0"
    "modifier\0contextMenu\0pos\0selectionChanged\0"
    "QItemSelection\0selected\0deselected\0"
    "showTodo\0editTodo\0deleteTodo\0newTodo\0"
    "newSubTodo\0copyTodoToDate\0"
    "scheduleResizeColumns\0resizeColumns\0"
    "itemDoubleClicked\0setNewDate\0"
    "setNewPercentage\0QAction*\0action\0"
    "setNewPriority\0changedCategories\0"
    "setFullView\0fullView\0setFlatView\0"
    "flatView\0notifyOtherViews\0onRowsInserted\0"
    "parent\0onTagsFetched\0KJob*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__TodoView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      44,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  234,    2, 0x06 /* Public */,
       3,    0,  235,    2, 0x06 /* Public */,
       4,    0,  236,    2, 0x06 /* Public */,
       5,    0,  237,    2, 0x06 /* Public */,
       6,    1,  238,    2, 0x06 /* Public */,
       8,    0,  241,    2, 0x06 /* Public */,
       9,    0,  242,    2, 0x06 /* Public */,
      10,    1,  243,    2, 0x06 /* Public */,
      13,    1,  246,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    1,  249,    2, 0x0a /* Public */,
      17,    3,  252,    2, 0x0a /* Public */,
      17,    2,  259,    2, 0x2a /* Public | MethodCloned */,
      21,    2,  264,    2, 0x0a /* Public */,
      25,    0,  269,    2, 0x0a /* Public */,
      26,    2,  270,    2, 0x0a /* Public */,
      30,    0,  275,    2, 0x0a /* Public */,
      31,    0,  276,    2, 0x0a /* Public */,
      32,    1,  277,    2, 0x0a /* Public */,
      34,    0,  280,    2, 0x0a /* Public */,
      35,    0,  281,    2, 0x0a /* Public */,
      10,    0,  282,    2, 0x0a /* Public */,
      13,    0,  283,    2, 0x0a /* Public */,
      36,    1,  284,    2, 0x09 /* Protected */,
      38,    1,  287,    2, 0x09 /* Protected */,
      41,    1,  290,    2, 0x09 /* Protected */,
      43,    2,  293,    2, 0x09 /* Protected */,
      47,    0,  298,    2, 0x09 /* Protected */,
      48,    0,  299,    2, 0x09 /* Protected */,
      49,    0,  300,    2, 0x09 /* Protected */,
      50,    0,  301,    2, 0x09 /* Protected */,
      51,    0,  302,    2, 0x09 /* Protected */,
      52,    1,  303,    2, 0x09 /* Protected */,
      53,    0,  306,    2, 0x08 /* Private */,
      54,    0,  307,    2, 0x08 /* Private */,
      55,    1,  308,    2, 0x08 /* Private */,
      56,    1,  311,    2, 0x08 /* Private */,
      57,    1,  314,    2, 0x08 /* Private */,
      60,    1,  317,    2, 0x08 /* Private */,
      61,    1,  320,    2, 0x08 /* Private */,
      62,    1,  323,    2, 0x08 /* Private */,
      64,    2,  326,    2, 0x08 /* Private */,
      64,    1,  331,    2, 0x28 /* Private | MethodCloned */,
      67,    3,  334,    2, 0x08 /* Private */,
      69,    1,  341,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 11,   12,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate, QMetaType::QDate,   18,   19,   20,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate,   18,   19,
    QMetaType::Void, 0x80000000 | 22, QMetaType::QDate,   23,   24,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11, 0x80000000 | 28,   27,   29,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,   33,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 37,    2,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void, QMetaType::QPoint,   42,
    QMetaType::Void, 0x80000000 | 44, 0x80000000 | 44,   45,   46,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QDate,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,   33,
    QMetaType::Void, QMetaType::QDate,   24,
    QMetaType::Void, 0x80000000 | 58,   59,
    QMetaType::Void, 0x80000000 | 58,   59,
    QMetaType::Void, 0x80000000 | 58,   59,
    QMetaType::Void, QMetaType::Bool,   63,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,   65,   66,
    QMetaType::Void, QMetaType::Bool,   65,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   68,   18,   19,
    QMetaType::Void, 0x80000000 | 70,    2,

       0        // eod
};

void EventViews::TodoView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TodoView *_t = static_cast<TodoView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->purgeCompletedSignal(); break;
        case 1: _t->unSubTodoSignal(); break;
        case 2: _t->unAllSubTodoSignal(); break;
        case 3: _t->configChanged(); break;
        case 4: _t->fullViewChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->printPreviewTodo(); break;
        case 6: _t->printTodo(); break;
        case 7: _t->createNote((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 8: _t->createEvent((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 9: _t->setIncidenceChanger((*reinterpret_cast< Akonadi::IncidenceChanger*(*)>(_a[1]))); break;
        case 10: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2])),(*reinterpret_cast< const QDate(*)>(_a[3]))); break;
        case 11: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 12: _t->showIncidences((*reinterpret_cast< const Akonadi::Item::List(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 13: _t->updateView(); break;
        case 14: _t->changeIncidenceDisplay((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< Akonadi::IncidenceChanger::ChangeType(*)>(_a[2]))); break;
        case 15: _t->updateConfig(); break;
        case 16: _t->clearSelection(); break;
        case 17: _t->expandIndex((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 18: _t->restoreViewState(); break;
        case 19: _t->saveViewState(); break;
        case 20: _t->createNote(); break;
        case 21: _t->createEvent(); break;
        case 22: _t->resizeEvent((*reinterpret_cast< QResizeEvent*(*)>(_a[1]))); break;
        case 23: _t->addQuickTodo((*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[1]))); break;
        case 24: _t->contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 25: _t->selectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 26: _t->showTodo(); break;
        case 27: _t->editTodo(); break;
        case 28: _t->deleteTodo(); break;
        case 29: _t->newTodo(); break;
        case 30: _t->newSubTodo(); break;
        case 31: _t->copyTodoToDate((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 32: _t->scheduleResizeColumns(); break;
        case 33: _t->resizeColumns(); break;
        case 34: _t->itemDoubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 35: _t->setNewDate((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 36: _t->setNewPercentage((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 37: _t->setNewPriority((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 38: _t->changedCategories((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 39: _t->setFullView((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 40: _t->setFlatView((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 41: _t->setFlatView((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 42: _t->onRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 43: _t->onTagsFetched((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item::List >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TodoView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::purgeCompletedSignal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TodoView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::unSubTodoSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TodoView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::unAllSubTodoSignal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (TodoView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::configChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (TodoView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::fullViewChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (TodoView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::printPreviewTodo)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (TodoView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::printTodo)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (TodoView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::createNote)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (TodoView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TodoView::createEvent)) {
                *result = 8;
                return;
            }
        }
    }
}

const QMetaObject EventViews::TodoView::staticMetaObject = {
    { &EventViews::EventView::staticMetaObject, qt_meta_stringdata_EventViews__TodoView.data,
      qt_meta_data_EventViews__TodoView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::TodoView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::TodoView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__TodoView.stringdata0))
        return static_cast<void*>(this);
    return EventViews::EventView::qt_metacast(_clname);
}

int EventViews::TodoView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventViews::EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void EventViews::TodoView::purgeCompletedSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::TodoView::unSubTodoSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EventViews::TodoView::unAllSubTodoSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EventViews::TodoView::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void EventViews::TodoView::fullViewChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void EventViews::TodoView::printPreviewTodo()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void EventViews::TodoView::printTodo()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void EventViews::TodoView::createNote(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void EventViews::TodoView::createEvent(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
