/****************************************************************************
** Meta object code from reading C++ file 'journalview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/journal/journalview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journalview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__JournalView_t {
    QByteArrayData data[29];
    char stringdata0[413];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__JournalView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__JournalView_t qt_meta_stringdata_EventViews__JournalView = {
    {
QT_MOC_LITERAL(0, 0, 23), // "EventViews::JournalView"
QT_MOC_LITERAL(1, 24, 12), // "flushEntries"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 25), // "setIncidenceChangerSignal"
QT_MOC_LITERAL(4, 64, 26), // "Akonadi::IncidenceChanger*"
QT_MOC_LITERAL(5, 91, 13), // "journalEdited"
QT_MOC_LITERAL(6, 105, 13), // "Akonadi::Item"
QT_MOC_LITERAL(7, 119, 7), // "journal"
QT_MOC_LITERAL(8, 127, 14), // "journalDeleted"
QT_MOC_LITERAL(9, 142, 12), // "printJournal"
QT_MOC_LITERAL(10, 155, 22), // "KCalCore::Journal::Ptr"
QT_MOC_LITERAL(11, 178, 7), // "preview"
QT_MOC_LITERAL(12, 186, 9), // "dayPassed"
QT_MOC_LITERAL(13, 196, 10), // "updateView"
QT_MOC_LITERAL(14, 207, 9), // "flushView"
QT_MOC_LITERAL(15, 217, 9), // "showDates"
QT_MOC_LITERAL(16, 227, 5), // "start"
QT_MOC_LITERAL(17, 233, 3), // "end"
QT_MOC_LITERAL(18, 237, 14), // "preferredMonth"
QT_MOC_LITERAL(19, 252, 14), // "showIncidences"
QT_MOC_LITERAL(20, 267, 19), // "Akonadi::Item::List"
QT_MOC_LITERAL(21, 287, 10), // "incidences"
QT_MOC_LITERAL(22, 298, 4), // "date"
QT_MOC_LITERAL(23, 303, 22), // "changeIncidenceDisplay"
QT_MOC_LITERAL(24, 326, 9), // "incidence"
QT_MOC_LITERAL(25, 336, 37), // "Akonadi::IncidenceChanger::Ch..."
QT_MOC_LITERAL(26, 374, 19), // "setIncidenceChanger"
QT_MOC_LITERAL(27, 394, 7), // "changer"
QT_MOC_LITERAL(28, 402, 10) // "newJournal"

    },
    "EventViews::JournalView\0flushEntries\0"
    "\0setIncidenceChangerSignal\0"
    "Akonadi::IncidenceChanger*\0journalEdited\0"
    "Akonadi::Item\0journal\0journalDeleted\0"
    "printJournal\0KCalCore::Journal::Ptr\0"
    "preview\0dayPassed\0updateView\0flushView\0"
    "showDates\0start\0end\0preferredMonth\0"
    "showIncidences\0Akonadi::Item::List\0"
    "incidences\0date\0changeIncidenceDisplay\0"
    "incidence\0Akonadi::IncidenceChanger::ChangeType\0"
    "setIncidenceChanger\0changer\0newJournal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__JournalView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x06 /* Public */,
       3,    1,   85,    2, 0x06 /* Public */,
       5,    1,   88,    2, 0x06 /* Public */,
       8,    1,   91,    2, 0x06 /* Public */,
       9,    2,   94,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    1,   99,    2, 0x0a /* Public */,
      13,    0,  102,    2, 0x0a /* Public */,
      14,    0,  103,    2, 0x0a /* Public */,
      15,    3,  104,    2, 0x0a /* Public */,
      15,    2,  111,    2, 0x2a /* Public | MethodCloned */,
      19,    2,  116,    2, 0x0a /* Public */,
      23,    2,  121,    2, 0x0a /* Public */,
      26,    1,  126,    2, 0x0a /* Public */,
      28,    0,  129,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Bool,    2,   11,

 // slots: parameters
    QMetaType::Void, QMetaType::QDate,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate, QMetaType::QDate,   16,   17,   18,
    QMetaType::Void, QMetaType::QDate, QMetaType::QDate,   16,   17,
    QMetaType::Void, 0x80000000 | 20, QMetaType::QDate,   21,   22,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 25,   24,    2,
    QMetaType::Void, 0x80000000 | 4,   27,
    QMetaType::Void,

       0        // eod
};

void EventViews::JournalView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JournalView *_t = static_cast<JournalView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->flushEntries(); break;
        case 1: _t->setIncidenceChangerSignal((*reinterpret_cast< Akonadi::IncidenceChanger*(*)>(_a[1]))); break;
        case 2: _t->journalEdited((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 3: _t->journalDeleted((*reinterpret_cast< const Akonadi::Item(*)>(_a[1]))); break;
        case 4: _t->printJournal((*reinterpret_cast< const KCalCore::Journal::Ptr(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->dayPassed((*reinterpret_cast< const QDate(*)>(_a[1]))); break;
        case 6: _t->updateView(); break;
        case 7: _t->flushView(); break;
        case 8: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2])),(*reinterpret_cast< const QDate(*)>(_a[3]))); break;
        case 9: _t->showDates((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 10: _t->showIncidences((*reinterpret_cast< const Akonadi::Item::List(*)>(_a[1])),(*reinterpret_cast< const QDate(*)>(_a[2]))); break;
        case 11: _t->changeIncidenceDisplay((*reinterpret_cast< const Akonadi::Item(*)>(_a[1])),(*reinterpret_cast< Akonadi::IncidenceChanger::ChangeType(*)>(_a[2]))); break;
        case 12: _t->setIncidenceChanger((*reinterpret_cast< Akonadi::IncidenceChanger*(*)>(_a[1]))); break;
        case 13: _t->newJournal(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KCalCore::Journal::Ptr >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item::List >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::Item >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (JournalView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalView::flushEntries)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (JournalView::*_t)(Akonadi::IncidenceChanger * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalView::setIncidenceChangerSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (JournalView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalView::journalEdited)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (JournalView::*_t)(const Akonadi::Item & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalView::journalDeleted)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (JournalView::*_t)(const KCalCore::Journal::Ptr & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&JournalView::printJournal)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject EventViews::JournalView::staticMetaObject = {
    { &EventView::staticMetaObject, qt_meta_stringdata_EventViews__JournalView.data,
      qt_meta_data_EventViews__JournalView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::JournalView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::JournalView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__JournalView.stringdata0))
        return static_cast<void*>(this);
    return EventView::qt_metacast(_clname);
}

int EventViews::JournalView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void EventViews::JournalView::flushEntries()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::JournalView::setIncidenceChangerSignal(Akonadi::IncidenceChanger * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void EventViews::JournalView::journalEdited(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void EventViews::JournalView::journalDeleted(const Akonadi::Item & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void EventViews::JournalView::printJournal(const KCalCore::Journal::Ptr & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
