#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'timescaleedit_base.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TIMESCALEEDIT_BASE_H
#define UI_TIMESCALEEDIT_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_TimeScaleEditWidget
{
public:
    QVBoxLayout *vboxLayout;
    KComboBox *zoneCombo;
    QHBoxLayout *hboxLayout;
    QListWidget *listWidget;
    QVBoxLayout *vboxLayout1;
    QPushButton *addButton;
    QPushButton *upButton;
    QPushButton *downButton;
    QPushButton *removeButton;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *TimeScaleEditWidget)
    {
        if (TimeScaleEditWidget->objectName().isEmpty())
            TimeScaleEditWidget->setObjectName(QStringLiteral("TimeScaleEditWidget"));
        TimeScaleEditWidget->resize(400, 320);
        vboxLayout = new QVBoxLayout(TimeScaleEditWidget);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        zoneCombo = new KComboBox(TimeScaleEditWidget);
        zoneCombo->setObjectName(QStringLiteral("zoneCombo"));

        vboxLayout->addWidget(zoneCombo);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        listWidget = new QListWidget(TimeScaleEditWidget);
        listWidget->setObjectName(QStringLiteral("listWidget"));

        hboxLayout->addWidget(listWidget);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        addButton = new QPushButton(TimeScaleEditWidget);
        addButton->setObjectName(QStringLiteral("addButton"));

        vboxLayout1->addWidget(addButton);

        upButton = new QPushButton(TimeScaleEditWidget);
        upButton->setObjectName(QStringLiteral("upButton"));

        vboxLayout1->addWidget(upButton);

        downButton = new QPushButton(TimeScaleEditWidget);
        downButton->setObjectName(QStringLiteral("downButton"));

        vboxLayout1->addWidget(downButton);

        removeButton = new QPushButton(TimeScaleEditWidget);
        removeButton->setObjectName(QStringLiteral("removeButton"));

        vboxLayout1->addWidget(removeButton);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem);


        hboxLayout->addLayout(vboxLayout1);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(TimeScaleEditWidget);

        QMetaObject::connectSlotsByName(TimeScaleEditWidget);
    } // setupUi

    void retranslateUi(QWidget *TimeScaleEditWidget)
    {
        addButton->setText(QString());
        upButton->setText(QString());
        downButton->setText(QString());
        removeButton->setText(QString());
        Q_UNUSED(TimeScaleEditWidget);
    } // retranslateUi

};

namespace Ui {
    class TimeScaleEditWidget: public Ui_TimeScaleEditWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TIMESCALEEDIT_BASE_H

