/****************************************************************************
** Meta object code from reading C++ file 'calendardecoration.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/eventviews-17.12.3/src/agenda/calendardecoration.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendardecoration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventViews__CalendarDecoration__Element_t {
    QByteArrayData data[7];
    char stringdata0[115];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__CalendarDecoration__Element_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__CalendarDecoration__Element_t qt_meta_stringdata_EventViews__CalendarDecoration__Element = {
    {
QT_MOC_LITERAL(0, 0, 39), // "EventViews::CalendarDecoratio..."
QT_MOC_LITERAL(1, 40, 12), // "gotNewPixmap"
QT_MOC_LITERAL(2, 53, 0), // ""
QT_MOC_LITERAL(3, 54, 15), // "gotNewShortText"
QT_MOC_LITERAL(4, 70, 14), // "gotNewLongText"
QT_MOC_LITERAL(5, 85, 19), // "gotNewExtensiveText"
QT_MOC_LITERAL(6, 105, 9) // "gotNewUrl"

    },
    "EventViews::CalendarDecoration::Element\0"
    "gotNewPixmap\0\0gotNewShortText\0"
    "gotNewLongText\0gotNewExtensiveText\0"
    "gotNewUrl"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__CalendarDecoration__Element[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       3,    1,   42,    2, 0x06 /* Public */,
       4,    1,   45,    2, 0x06 /* Public */,
       5,    1,   48,    2, 0x06 /* Public */,
       6,    1,   51,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QPixmap,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QUrl,    2,

       0        // eod
};

void EventViews::CalendarDecoration::Element::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Element *_t = static_cast<Element *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->gotNewPixmap((*reinterpret_cast< const QPixmap(*)>(_a[1]))); break;
        case 1: _t->gotNewShortText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->gotNewLongText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->gotNewExtensiveText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->gotNewUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Element::*_t)(const QPixmap & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Element::gotNewPixmap)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Element::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Element::gotNewShortText)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Element::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Element::gotNewLongText)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Element::*_t)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Element::gotNewExtensiveText)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Element::*_t)(const QUrl & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Element::gotNewUrl)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject EventViews::CalendarDecoration::Element::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_EventViews__CalendarDecoration__Element.data,
      qt_meta_data_EventViews__CalendarDecoration__Element,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::CalendarDecoration::Element::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::CalendarDecoration::Element::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__CalendarDecoration__Element.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EventViews::CalendarDecoration::Element::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void EventViews::CalendarDecoration::Element::gotNewPixmap(const QPixmap & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< EventViews::CalendarDecoration::Element *>(this), &staticMetaObject, 0, _a);
}

// SIGNAL 1
void EventViews::CalendarDecoration::Element::gotNewShortText(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< EventViews::CalendarDecoration::Element *>(this), &staticMetaObject, 1, _a);
}

// SIGNAL 2
void EventViews::CalendarDecoration::Element::gotNewLongText(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< EventViews::CalendarDecoration::Element *>(this), &staticMetaObject, 2, _a);
}

// SIGNAL 3
void EventViews::CalendarDecoration::Element::gotNewExtensiveText(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< EventViews::CalendarDecoration::Element *>(this), &staticMetaObject, 3, _a);
}

// SIGNAL 4
void EventViews::CalendarDecoration::Element::gotNewUrl(const QUrl & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< EventViews::CalendarDecoration::Element *>(this), &staticMetaObject, 4, _a);
}
struct qt_meta_stringdata_EventViews__CalendarDecoration__StoredElement_t {
    QByteArrayData data[1];
    char stringdata0[46];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__CalendarDecoration__StoredElement_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__CalendarDecoration__StoredElement_t qt_meta_stringdata_EventViews__CalendarDecoration__StoredElement = {
    {
QT_MOC_LITERAL(0, 0, 45) // "EventViews::CalendarDecoratio..."

    },
    "EventViews::CalendarDecoration::StoredElement"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__CalendarDecoration__StoredElement[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void EventViews::CalendarDecoration::StoredElement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject EventViews::CalendarDecoration::StoredElement::staticMetaObject = {
    { &Element::staticMetaObject, qt_meta_stringdata_EventViews__CalendarDecoration__StoredElement.data,
      qt_meta_data_EventViews__CalendarDecoration__StoredElement,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::CalendarDecoration::StoredElement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::CalendarDecoration::StoredElement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__CalendarDecoration__StoredElement.stringdata0))
        return static_cast<void*>(this);
    return Element::qt_metacast(_clname);
}

int EventViews::CalendarDecoration::StoredElement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Element::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_EventViews__CalendarDecoration__DecorationFactory_t {
    QByteArrayData data[1];
    char stringdata0[50];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventViews__CalendarDecoration__DecorationFactory_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventViews__CalendarDecoration__DecorationFactory_t qt_meta_stringdata_EventViews__CalendarDecoration__DecorationFactory = {
    {
QT_MOC_LITERAL(0, 0, 49) // "EventViews::CalendarDecoratio..."

    },
    "EventViews::CalendarDecoration::DecorationFactory"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventViews__CalendarDecoration__DecorationFactory[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void EventViews::CalendarDecoration::DecorationFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject EventViews::CalendarDecoration::DecorationFactory::staticMetaObject = {
    { &CalendarSupport::PluginFactory::staticMetaObject, qt_meta_stringdata_EventViews__CalendarDecoration__DecorationFactory.data,
      qt_meta_data_EventViews__CalendarDecoration__DecorationFactory,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *EventViews::CalendarDecoration::DecorationFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::CalendarDecoration::DecorationFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventViews__CalendarDecoration__DecorationFactory.stringdata0))
        return static_cast<void*>(this);
    return CalendarSupport::PluginFactory::qt_metacast(_clname);
}

int EventViews::CalendarDecoration::DecorationFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CalendarSupport::PluginFactory::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
